#ifndef lint
static const char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
#endif

#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYPATCH 20130304

#define YYEMPTY        (-1)
#define yyclearin      (yychar = YYEMPTY)
#define yyerrok        (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)

#define YYPREFIX "yy"

#define YYPURE 0

#line 22 "parse.y"
#include <sys/types.h>
#include <sys/stat.h>

#include <ctype.h>
#include <grp.h>
#include <pwd.h>
#include <string.h>
#include <syslog.h>

#include "fdm.h"
#include "deliver.h"
#include "fetch.h"
#include "match.h"

struct strb	*parse_tags;
struct macros	 parse_macros;
struct macro	*parse_last;	/* last command-line argument macro */

u_int		 parse_ruleidx;
u_int		 parse_actionidx;

ARRAY_DECL(, struct rule *) parse_rulestack;
struct rule	*parse_rule;

struct files	 parse_filestack;
struct file	*parse_file;

int		 yyparse(void);

int
parse_conf(const char *path, struct strings *macros)
{
	struct macro	*macro;
	FILE		*f;
	u_int		 i;

        if ((f = fopen(path, "r")) == NULL)
                return (-1);

	ARRAY_INIT(&parse_rulestack);
	parse_rule = NULL;

	ARRAY_INIT(&parse_filestack);
	parse_file = xmalloc(sizeof *parse_file);

	parse_file->f = f;
	parse_file->line = 0;
	parse_file->path = path;

	strb_create(&parse_tags);
	default_tags(&parse_tags, NULL);
	add_tag(&parse_tags, "home", "%s", conf.user_home);

	TAILQ_INIT(&parse_macros);
	parse_last = NULL;
	for (i = 0; i < ARRAY_LENGTH(macros); i++) {
		parse_last = extract_macro(ARRAY_ITEM(macros, i));
		TAILQ_INSERT_TAIL(&parse_macros, parse_last, entry);
	}

	parse_file->line++;
        yyparse();

	if (!ARRAY_EMPTY(&parse_rulestack))
		yyerror("missing }");
	ARRAY_FREE(&parse_rulestack);

	ARRAY_FREE(&parse_filestack);
	xfree(parse_file);

	while (!TAILQ_EMPTY(&parse_macros)) {
		macro = TAILQ_FIRST(&parse_macros);
		TAILQ_REMOVE(&parse_macros, macro, entry);

		if (macro->type == MACRO_STRING)
			xfree(macro->value.str);
		xfree(macro);
	}

	strb_destroy(&parse_tags);

        fclose(f);
        return (0);
}

__dead printflike1 void
yyerror(const char *fmt, ...)
{
	va_list	ap;
	char   *s;

	xasprintf(&s,
	    "%s: %s at line %d", parse_file->path, fmt, parse_file->line);

	va_start(ap, fmt);
	log_vwrite(LOG_CRIT, s, ap);
	va_end(ap);

	exit(1);
}
#line 247 "parse.y"
#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
typedef union
{
	long long 	 	 number;
        char 			*string;
	int 		 	 flag;
	u_int			 locks;
	struct {
		struct fetch	*fetch;
		void		*data;
	} fetch;
	struct {
		char		*host;
		char		*port;
	} server;
	enum area	 	 area;
	enum exprop		 exprop;
	struct actitem 		*actitem;
	struct actlist 		*actlist;
	struct expr		*expr;
	struct expritem		*expritem;
	struct strings		*strings;
	struct replstrs		*replstrs;
	enum fetch_only		 only;
	struct {
		char		*path;
		enum fetch_only	 only;
	} poponly;
	struct {
		int		 flags;
		char		*str;
	} re;
	gid_t			 localgid;
	enum cmp		 cmp;
	struct rule		*rule;
	struct {
		char		*user;
		int		 user_netrc;
		char		*pass;
		int		 pass_netrc;
	} userpass;
	userfunction		 ufn;
	struct userfunctions    *ufns;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
#line 171 "y.tab.c"

/* compatibility with bison */
#ifdef YYPARSE_PARAM
/* compatibility with FreeBSD */
# ifdef YYPARSE_PARAM_TYPE
#  define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#  define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
# define YYPARSE_DECL() yyparse(void)
#endif

/* Parameters sent to lex. */
#ifdef YYLEX_PARAM
# define YYLEX_DECL() yylex(void *YYLEX_PARAM)
# define YYLEX yylex(YYLEX_PARAM)
#else
# define YYLEX_DECL() yylex(void)
# define YYLEX yylex()
#endif

/* Parameters sent to yyerror. */
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(msg)
#endif

extern int YYPARSE_DECL();

#define TOKACCOUNT 257
#define TOKACCOUNTS 258
#define TOKACTION 259
#define TOKACTIONS 260
#define TOKADDHEADER 261
#define TOKADDTOCACHE 262
#define TOKAGE 263
#define TOKALL 264
#define TOKALLOWMANY 265
#define TOKAND 266
#define TOKANYNAME 267
#define TOKANYSIZE 268
#define TOKANYTYPE 269
#define TOKAPPEND 270
#define TOKATTACHMENT 271
#define TOKBODY 272
#define TOKBYTES 273
#define TOKCACHE 274
#define TOKCASE 275
#define TOKCMDUSER 276
#define TOKCOMPRESS 277
#define TOKCONTINUE 278
#define TOKCOUNT 279
#define TOKCOURIER 280
#define TOKDAYS 281
#define TOKDEFUSER 282
#define TOKDELTOOBIG 283
#define TOKDISABLED 284
#define TOKDOMAIN 285
#define TOKDOTLOCK 286
#define TOKDROP 287
#define TOKEQ 288
#define TOKEXEC 289
#define TOKEXPIRE 290
#define TOKFCNTL 291
#define TOKFILEGROUP 292
#define TOKFILEUMASK 293
#define TOKFLOCK 294
#define TOKFOLDER 295
#define TOKFOLDERS 296
#define TOKFROM 297
#define TOKGIGABYTES 298
#define TOKGROUP 299
#define TOKGROUPS 300
#define TOKHEADER 301
#define TOKHEADERS 302
#define TOKHOURS 303
#define TOKIMAP 304
#define TOKIMAPS 305
#define TOKIMPLACT 306
#define TOKIN 307
#define TOKINCACHE 308
#define TOKINVALID 309
#define TOKKEEP 310
#define TOKKEY 311
#define TOKKILOBYTES 312
#define TOKLOCKFILE 313
#define TOKLOCKTYPES 314
#define TOKLOOKUPORDER 315
#define TOKMAILDIR 316
#define TOKMAILDIRS 317
#define TOKMATCH 318
#define TOKMATCHED 319
#define TOKMAXSIZE 320
#define TOKMBOX 321
#define TOKMBOXES 322
#define TOKMEGABYTES 323
#define TOKMINUTES 324
#define TOKMONTHS 325
#define TOKNE 326
#define TOKNEWONLY 327
#define TOKNNTP 328
#define TOKNNTPS 329
#define TOKNOAPOP 330
#define TOKNOCRAMMD5 331
#define TOKNOCREATE 332
#define TOKNOLOGIN 333
#define TOKNONE 334
#define TOKNORECEIVED 335
#define TOKNOT 336
#define TOKNOUIDL 337
#define TOKNOVERIFY 338
#define TOKOLDONLY 339
#define TOKOR 340
#define TOKPARALLELACCOUNTS 341
#define TOKPASS 342
#define TOKPASSWD 343
#define TOKPIPE 344
#define TOKPOP3 345
#define TOKPOP3S 346
#define TOKPORT 347
#define TOKPROXY 348
#define TOKPURGEAFTER 349
#define TOKQUEUEHIGH 350
#define TOKQUEUELOW 351
#define TOKREMOVEFROMCACHE 352
#define TOKREMOVEHEADER 353
#define TOKREMOVEHEADERS 354
#define TOKRETURNS 355
#define TOKREWRITE 356
#define TOKSECONDS 357
#define TOKSERVER 358
#define TOKSET 359
#define TOKSIZE 360
#define TOKSMTP 361
#define TOKSTDIN 362
#define TOKSTDOUT 363
#define TOKSTRING 364
#define TOKSTRIPCHARACTERS 365
#define TOKTAG 366
#define TOKTAGGED 367
#define TOKTIMEOUT 368
#define TOKTO 369
#define TOKTOTALSIZE 370
#define TOKUNMATCHED 371
#define TOKUSER 372
#define TOKUSERS 373
#define TOKVALUE 374
#define TOKVERIFYCERTS 375
#define TOKWEEKS 376
#define TOKWRITE 377
#define TOKYEARS 378
#define NONE 379
#define NUMBER 380
#define STRING 381
#define STRMACRO 382
#define NUMMACRO 383
#define STRCOMMAND 384
#define NUMCOMMAND 385
#define YYERRCODE 256
static const short yylhs[] = {                           -1,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   77,
   77,   78,   78,   79,   79,   80,   80,   81,   81,   82,
   82,   83,   83,   84,   84,   54,   54,   55,   55,   50,
   50,   50,   51,   51,   32,   32,   32,   52,   53,   30,
   30,   30,   30,   30,   31,   31,   31,   31,   31,   31,
   31,   31,   34,   34,   76,   74,   74,   74,   74,   74,
   74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
   74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
   72,   72,   38,   38,   58,   58,   59,   59,   68,   68,
   69,   69,   40,   40,   60,   60,   61,   61,   63,   63,
   28,   28,   28,   29,   29,   29,   27,   27,   57,   57,
   42,   42,   42,   43,   43,   13,   13,   15,   15,   14,
   14,   47,   47,   46,   46,   48,   48,   49,   49,   18,
   18,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    2,    2,   71,
   71,   41,   41,   39,   39,   12,   12,    3,    3,    3,
    3,   33,   33,   44,   44,    5,    5,    6,    6,    4,
    4,   16,   16,   17,   17,   10,   10,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    8,    8,    7,    7,   45,   45,
   45,   45,   75,   73,   64,   64,   56,   56,   62,   62,
   24,   24,   25,   25,   26,   26,   19,   19,   20,   20,
   35,   35,   21,   21,   22,   22,   23,   23,   67,   67,
   67,   67,   66,   65,   65,   37,   37,   36,   36,   11,
   11,   11,   11,   11,   11,   11,   11,   70,
};
static const short yylen[] = {                            2,
    0,    2,    2,    2,    2,    2,    2,    2,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    2,    1,    2,    0,    1,
    1,    1,    1,    3,    1,    1,    1,    1,    1,    1,
    2,    2,    2,    2,    1,    2,    2,    2,    2,    2,
    2,    2,    2,    0,    3,    3,    3,    3,    2,    2,
    3,    3,    3,    3,    3,    3,    3,    3,    2,    3,
    3,    3,    3,    2,    2,    3,    3,    3,    3,    3,
    3,    3,    2,    1,    2,    1,    2,    1,    1,    1,
    2,    1,    2,    4,    2,    4,    2,    4,    2,    4,
    1,    1,    1,    2,    1,    1,    1,    1,    0,    2,
    0,    2,    4,    2,    1,    1,    0,    1,    0,    1,
    0,    2,    2,    3,    2,    0,    2,    0,    2,    1,
    0,    2,    2,    2,    2,    1,    3,    3,    7,    4,
    1,    3,    4,    4,    1,    1,    1,    2,    1,    4,
    6,    2,    4,    2,    4,    0,    1,    0,    2,    2,
    2,    1,    0,    1,    0,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    2,    3,    2,
   10,    3,    4,    5,    5,    2,    2,    4,    3,    5,
    5,    5,    4,    4,    3,    2,    1,    2,    4,    6,
    3,    1,    1,    3,    0,    1,    0,    2,    2,    4,
    1,    0,    1,    0,    1,    0,    1,    0,    1,    0,
    1,    1,    1,    1,    1,    1,    1,    1,    4,    0,
    2,    2,    4,    1,    0,    3,    0,    1,    0,    7,
    6,    8,    6,    1,    1,    1,    7,    6,
};
static const short yydefred[] = {                         1,
    0,    0,    0,    0,    0,    0,    9,    0,    0,  203,
    2,    3,    4,    5,    6,    7,    8,   31,   32,   30,
   33,    0,    0,    0,    0,    0,  116,    0,    0,    0,
   60,    0,    0,   59,    0,    0,    0,    0,    0,    0,
    0,   75,   74,    0,    0,    0,    0,    0,    0,    0,
   69,    0,    0,    0,  120,    0,   12,   13,    0,    0,
    0,   55,  202,    0,  204,  176,  177,    0,    0,   14,
   15,    0,  178,    0,    0,  172,    0,  186,  173,    0,
    0,    0,  187,    0,  180,    0,  115,    0,    0,    0,
   76,   36,   37,   35,   77,  108,  107,   78,   80,   71,
   70,   58,  103,  101,  102,  106,  105,    0,   90,   89,
   92,    0,   56,    0,   67,   68,   73,   72,   65,   66,
    0,   64,    0,    0,   82,   34,    0,   10,   11,    0,
    0,  175,  146,  225,  226,  147,    0,    0,    0,   24,
   25,    0,    0,  141,    0,  174,    0,  150,    0,    0,
    0,  145,  136,    0,    0,    0,    0,   53,    0,    0,
    0,  196,  189,  166,  167,    0,    0,    0,    0,    0,
    0,  114,    0,    0,    0,    0,    0,    0,  179,    0,
    0,  104,   91,   41,   44,   42,   43,   49,   46,   47,
   51,   48,   50,   52,    0,   20,   21,   22,   23,  227,
  228,    0,  224,  244,    0,    0,    0,    0,  245,  246,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  149,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  157,  201,    0,    0,  195,  188,    0,    0,
    0,  168,  169,    0,  170,  171,    0,    0,  183,    0,
    0,    0,  159,  161,  160,    0,    0,    0,  118,  248,
    0,    0,    0,    0,   95,    0,   97,    0,    0,  137,
    0,  130,  138,    0,    0,    0,    0,    0,  142,  151,
  148,    0,    0,    0,    0,    0,  113,    0,    0,  199,
  192,  190,  191,    0,  184,    0,    0,  153,    0,    0,
    0,    0,    0,   88,    0,    0,    0,    0,    0,    0,
  124,    0,    0,  140,    0,  232,    0,   18,   19,    0,
    0,  155,   94,    0,    0,    0,    0,  234,    0,  221,
  222,    0,    0,  206,    0,    0,   16,   17,    0,    0,
   96,   87,   98,  123,  122,    0,    0,  217,    0,    0,
  200,  162,    0,    0,    0,    0,    0,  219,    0,  238,
    0,    0,   99,    0,    0,  209,  229,  211,    0,    0,
    0,  243,  241,  236,    0,    0,   86,    0,    0,    0,
  213,  139,  164,    0,  233,  215,  240,    0,  100,   85,
  247,  210,  181,  242,
};
static const short yydgoto[] = {                          1,
  222,  223,  179,  244,  166,  246,   28,   68,   29,   69,
  205,  234,   30,   56,  260,  149,  150,  273,  349,  359,
  206,  151,  208,  369,  382,  387,   95,  107,  108,  113,
  122,  114,  353,   62,  332,  361,  333,  285,  152,  153,
   85,   59,   86,  384,   65,  220,  311,  314,  277,   21,
   22,   87,  304,  270,  279,  320,  252,  378,  305,  209,
  210,  339,  334,  335,  327,  328,  284,  111,  112,   11,
   12,   13,   14,   15,   16,   17,  154,   60,   88,  340,
  336,  211,  212,  155,
};
static const short yysindex[] = {                         0,
  454, -249, -249, -249, -262, 3669,    0,   21,   50,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   72, -156, -272,   72, -159,    0, -120, -235, 2990,
    0, -249, -249,    0, -169, -310, -246, -249, -237, -244,
 -302,    0,    0, -302, -249, -296, -302, -302, -249, -302,
    0, -249, -302, -249,    0, -272,    0,    0, 3355, -112,
 -302,    0,    0, -103,    0,    0,    0, -235, -262,    0,
    0,  -27,    0, -224, -249,    0, -249,    0,    0,    3,
 -249, -249,    0, -249,    0, -171,    0, -104,   72,   72,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -196,    0,    0,
    0, -244,    0, -221,    0,    0,    0,    0,    0,    0,
   72,    0, -253,   72,    0,    0, -136,    0,    0, -249,
 -249,    0,    0,    0,    0,    0, -249, -249, -249,    0,
    0, -249, -217,    0, -249,    0, 3603,    0, -249, -249,
 -217,    0,    0,  -72,  -57, -249,   72,    0, -118, 3207,
 -262,    0,    0,    0,    0, -302, -249,    3, -249,  -58,
    3,    0, -163, -302,  -43,   72,  -35, -216,    0, -249,
   72,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -181,    0,    0,    0,    0,    0,
    0, -162,    0,    0, -126, -217, -217, -217,    0,    0,
  -13,   -5,  -23, -123,   72,  -36, -115,   72, -249, -100,
  -38,    0, 3453,   72,   72, -303, -249,   72, -249,   72,
 -108,   72,    0,    0, 3562, -118,    0,    0,   72, -302,
   72,    0,    0, -302,    0,    0, -302, -249,    0, -265,
 -249, -161,    0,    0,    0,   15, -249, -249,    0,    0,
 -303, -303, -303, -249,    0, -249,    0, -249,   72,    0,
 -249,    0,    0, -249, -149, -249, -170, -249,    0,    0,
    0, -249, -249, -130,   19,   26,    0,   72, 3494,    0,
    0,    0,    0,   72,    0,   72,  160,    0, -168, -168,
 -259, -130, -129,    0,   39,   49,   72,   72,   72, -146,
    0,   72, -249,    0,   72,    0, -140,    0,    0, -131,
 -249,    0,    0, -118, -302, -249, -130,    0, -259,    0,
    0,  -66, -113,    0, -259,    7,    0,    0,  -56,   11,
    0,    0,    0,    0,    0,   72, -249,    0, -110,   72,
    0,    0,  180, -111, -259, -113, -249,    0, -131,    0,
 -131, -249,    0, -249, -249,    0,    0,    0, -106, -265,
 -249,    0,    0,    0, -109, -110,    0,   58, -131,   62,
    0,    0,    0,  184,    0,    0,    0, -106,    0,    0,
    0,    0,    0,    0,
};
static const short yyrindex[] = {                         0,
    0,    0,    0,    0, 3025,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    1, -167, 3375,   76, 2607,    0,  -87, -117,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  494,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  -70, 3025,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, -107,    0,    0, 2723, 2748,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2770,    0,    0,
    0, 2791,    0, 2385,    0,    0,    0,    0,    0,    0,
 2797,    0, 2413, 2803,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3277,    0, 2822,    0,
 3025,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  233, -105,    0,    0,    0,
  311,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -116,    0,    0,    0,    0,    0,
    0, -101,    0,    0, 2830,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1098, 1166,    0, 1237,    0,  806,
 1305,    0,    0, 1415, 1483,  404,    0, 1554,    0, 1622,
    0,   66,    0,    0,    0, 2822,    0,    0,  357,    0,
  583,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  591, 2330, -124,    0,    0,    0,    0,    0, 1732,    0,
    0,    0,    0,    0,  167,    0, 1800,    0,    0,    0,
    0,    0,    0,  514,    0,    0,    0,   97,    0,    0,
    0,    0,    0,  595,    0,  -96,    0,    0, 2423,    0,
 2397, 2357,    0,    0,    0,    0, 1871, 1939, 2049,    0,
    0,  920,    0,    0, 2117,    0,  294,    0,    0,  738,
    0,    0,    0, 2822,  185,    0, 2524,    0, 2558,    0,
    0,    0, 2552,    0,  158,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2188,    0,    0,  988,  628,
    0,    0,    0,    0, 2595, 2620,    0,    0,  344,    0,
  936,    0,    0,    0,    0,    0,    0,    0, 2256,  191,
    0,    0,    0,    0, 2634, 2586,    0,    0, 2641,    0,
    0,    0,    0,    0,    0,    0,    0, 2653,    0,    0,
    0,    0,    0,    0,
};
static const short yygindex[] = {                         0,
  -46,    5,    0,    0,  -62,    0,    0,    0,  -48,  176,
    0, -212,    0,    0,    0,  215,    0,    0, -300, -102,
    0,  119,    0, -128, -139,    0,    0,  139,    0, -144,
  -39,  -21,    0,    0, -288,  -91,  -78, -122,  217,    0,
    0,   32, -241,    0,    0, -114,    0,    0,    0,  230,
 3186, 2940,    8,    0,    0,    0,    0,  -79,   25,    0,
    0,    0,    0,  -40,    0,   -7, -141,  183,    0,    0,
    0,    0,    0,    0,    0,    0,  235,    0,    0,    0,
   23,    0,    0,    0,
};
#define YYTABLESIZE 4044
static const short yytable[] = {                         54,
   38,  164,   63,  165,   54,  197,   54,   54,  295,   75,
  156,   26,  148,   96,   99,  158,  287,  174,  180,   54,
  162,  158,  115,  290,  118,  119,  120,  188,  123,  249,
   66,  125,  164,  231,  165,  109,  226,  117,  282,  123,
  100,   38,  167,  168,  169,  102,  360,  253,  103,  189,
  227,  184,  198,  104,  170,  254,  105,  256,  375,   64,
  376,   98,  164,  101,  165,  229,  360,  330,  283,   92,
  190,  191,   93,   27,   94,   39,  185,   92,  391,  331,
   93,   52,   94,   92,  173,  255,   93,  127,   94,  103,
  186,  261,  262,  263,  104,  291,  106,  105,  110,   57,
   58,  187,  293,  192,   67,  240,  286,  245,  247,  264,
   53,  351,  237,  236,   54,   18,   19,  266,   20,  301,
  302,  303,  193,   38,  194,   38,  238,   55,  383,  362,
   61,   18,   19,  365,   20,  178,  121,  121,  214,  298,
  219,  197,  197,  322,  123,  171,  217,  248,  121,  121,
  323,  158,  158,  121,  121,  128,  129,  239,  158,  233,
  121,  121,  257,  341,  318,  319,  125,  195,  135,  337,
  338,  111,  111,  343,  230,  230,  281,  121,  121,  196,
  197,  258,  389,  259,  198,  199,  392,  271,  198,  198,
   84,  200,  201,  297,  121,  274,  276,  310,  313,  325,
   39,  347,   91,  326,  121,  121,  348,  357,  202,  203,
   92,   18,   19,   93,   20,   94,  358,  364,  265,  267,
  368,   83,  292,  370,  393,  204,  381,  386,  163,  242,
  371,  165,  158,   92,   18,   19,   93,   20,   94,  289,
  272,  225,  281,  161,   84,  207,  182,  388,  394,  109,
  356,   57,   58,  373,  197,  197,  223,   38,  110,   38,
   38,   38,   38,  372,  158,  158,   38,  243,   18,   19,
   38,   20,   18,   19,   38,   20,   18,   19,   38,   20,
  159,  163,  239,  126,   38,  380,  355,   38,  344,   38,
  306,  125,  329,  231,  183,   38,   38,   38,  160,   38,
   38,  198,  198,  352,   38,   38,  321,   38,   18,   19,
   38,   20,  342,  342,    0,    0,   38,   38,   38,    0,
    0,   38,   38,   18,   19,  250,   20,   38,   38,   38,
   38,   38,   39,   38,   39,  278,  251,   38,   38,   38,
   38,    0,   38,  218,   38,   38,   38,   38,    0,   39,
  268,    0,   38,   38,   38,  182,   38,   18,   19,   38,
   20,   38,   38,   38,  374,   39,   38,   18,   19,   38,
   20,  379,   38,   38,    0,   18,   19,   38,   20,   38,
    0,   38,   38,   38,   38,   39,   39,   18,   19,    0,
   20,   18,   19,   39,   20,   18,   19,    0,   20,   18,
   19,    0,   20,  230,    0,   39,   18,   19,    0,   20,
    0,    0,   39,   39,  239,    0,  239,    0,  231,   18,
   19,    0,   20,  125,    0,  125,  125,  125,  125,   18,
   19,  239,   20,  152,   39,    0,  125,    0,   18,   19,
  125,   20,   18,   19,  125,   20,   84,   84,    0,   84,
    0,    0,    0,  125,   39,  125,   39,   39,   39,   39,
    0,  125,  125,  125,    0,  125,  125,  239,  218,    0,
  125,  125,    0,    0,    0,  239,  125,   83,   83,  194,
   83,    0,  125,    0,  125,    0,    0,  125,  239,    0,
  239,  182,  182,  125,    0,  239,  125,  125,  182,  125,
    0,    0,    0,  125,  125,  125,    0,    0,  125,    0,
  125,    0,    0,  207,    0,    0,  239,    0,  125,  125,
  125,    0,  125,    0,    0,  125,    0,  125,  230,  125,
    0,    0,  125,    0,    0,  125,  239,    0,  125,  239,
  239,    0,    0,  125,    0,  125,    0,    0,  125,  125,
  231,    0,  231,  231,  231,  231,    0,    0,    0,    0,
    0,    0,    0,  231,    0,    0,    0,  231,    0,  152,
  152,  231,  182,    0,    0,    0,  152,    0,   10,    0,
  231,    0,  231,    0,    0,    0,    0,    0,  231,  231,
  230,    0,  231,  231,    0,    0,    0,  231,  231,    0,
  218,    0,  218,  231,  182,  182,    0,    0,    0,  231,
    0,  231,    0,    0,  231,  194,  194,  218,    0,    0,
  231,    0,  194,  231,  231,    0,  231,  208,    0,    0,
  231,  231,  231,    0,    0,    0,    0,  231,  207,    0,
    0,    0,    0,    0,    0,  231,  231,  231,    0,  231,
  152,    0,  231,  218,  231,    0,  231,    0,    0,  231,
  230,  218,  230,  230,  230,  230,    0,    0,    0,    0,
  231,    0,  231,  230,    0,  231,  231,  230,    0,    0,
  218,  230,  152,  152,    0,    0,    0,    0,    0,    0,
  230,    0,  230,    0,    0,    0,  194,    0,  230,  230,
    0,    0,  218,    0,    0,  193,    0,  230,  230,    0,
    2,    0,    3,  230,    0,  230,    0,  185,    0,  230,
    0,  230,  218,    0,  230,  218,  218,    4,  194,  194,
    0,    0,    0,    0,  230,    0,  230,  218,    0,    0,
    0,  230,    0,    0,    0,    0,    0,  230,    0,    0,
    0,    0,  208,    0,    0,  230,  230,  230,    0,  230,
    0,    0,  230,    0,  230,    0,  230,    0,    0,  230,
  207,    5,  207,  207,  207,  207,    0,    0,    0,    0,
  230,    0,  230,  207,    0,  230,  230,  207,    0,    0,
    0,  207,    0,    0,    0,    0,    0,  111,  111,    0,
  207,    0,  207,    0,    0,  128,    0,    0,    0,  111,
  111,    0,    6,    0,  111,  111,    0,  207,  207,    0,
    0,  111,  111,  207,    0,    0,    0,    0,    0,  207,
    0,  207,    7,    0,  207,    8,    9,    0,  111,  111,
    0,  193,  193,    0,  207,    0,  207,  230,  193,  230,
    0,  207,    0,  185,  185,  111,    0,  207,    0,    0,
  185,    0,  218,    0,  230,  207,  207,  207,    0,  207,
    0,    0,  207,    0,  207,    0,  207,    0,    0,  207,
    0,    0,    0,    0,  208,    0,  208,  208,  208,  208,
  207,    0,  207,    0,    0,  207,  207,  208,    0,    0,
  230,  208,    0,    0,    0,  208,    0,    0,  230,    0,
    0,    0,    0,    0,  208,    0,  208,  230,    0,  129,
  230,    0,  193,    0,    0,    0,    0,  230,  230,  230,
  128,  208,  208,    0,  185,  218,    0,  208,    0,    0,
    0,    0,    0,  208,    0,  208,    0,    0,  208,  230,
    0,    0,    0,    0,  193,  193,    0,    0,  208,    0,
  208,    0,    0,    0,    0,  208,  185,  185,    0,  230,
    0,  208,  230,  230,    0,    0,    0,    0,    0,  208,
  208,  208,    0,  208,    0,    0,  208,  212,  208,    0,
  208,    0,    0,  208,  218,    0,  218,  218,  218,  218,
    0,    0,    0,    0,  208,    0,  208,  218,    0,  208,
  208,  218,    0,    0,    0,  218,    0,    0,    0,    0,
    0,    0,    0,    0,  218,    0,  218,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  218,  218,    0,  129,    0,    0,  218,    0,    0,
    0,    0,    0,  218,    0,  218,    0,    0,  218,    0,
  218,    0,  128,    0,  128,  128,  128,  128,  218,    0,
  218,    0,    0,    0,    0,  128,    0,    0,    0,  128,
    0,  218,    0,  128,    0,    0,    0,    0,    0,  218,
  218,  218,  128,  218,  128,    0,  218,  135,  218,    0,
  218,    0,    0,  218,    0,    0,    0,    0,    0,  128,
  128,    0,  212,    0,  218,  128,  218,    0,    0,  218,
  218,  128,    0,  128,    0,    0,  128,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  128,
    0,    0,    0,    0,    0,    0,    0,  128,  128,  128,
    0,  128,    0,    0,  128,  131,  128,    0,  128,    0,
    0,  128,    0,    0,  128,    0,  129,    0,  129,  129,
  129,  129,  128,    0,  128,    0,    0,  128,  128,  129,
    0,    0,  218,  129,  218,    0,    0,  129,    0,    0,
    0,    0,    0,    0,    0,    0,  129,    0,  129,  218,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  135,  129,  129,    0,    0,    0,    0,  129,
    0,    0,    0,    0,    0,  129,  133,  129,    0,    0,
  129,    0,    0,    0,  212,  218,  212,  212,  212,  212,
    0,    0,    0,  218,    0,    0,    0,  212,    0,    0,
    0,  212,    0,  129,    0,  212,  218,    0,  218,    0,
    0,  129,  129,  129,  212,  129,  212,    0,  129,    0,
  129,    0,  129,    0,    0,  129,    0,    0,  129,    0,
  131,  212,  212,    0,  218,    0,  129,  212,  129,    0,
    0,  129,  129,  212,   29,  212,    0,    0,  212,    0,
    0,    0,    0,    0,  218,    0,    0,  218,  218,    0,
  212,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  212,    0,    0,    0,    0,    0,    0,    0,  212,
  212,  212,    0,  212,    0,    0,  212,    0,  212,    0,
  212,    0,    0,  212,  135,    0,  135,  135,  135,  135,
    0,  133,    0,    0,  212,    0,  212,  135,    0,  212,
  212,  135,    0,    0,    0,  135,    0,    0,    0,    0,
    0,    0,    0,    0,  135,    0,  135,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  135,  135,    0,    0,    0,    0,  135,    0,    0,
    0,    0,    0,  135,  132,  135,    0,    0,  135,    0,
    0,    0,  131,    0,  131,  131,  131,  131,    0,   29,
    0,    0,    0,    0,    0,  131,    0,    0,    0,  131,
    0,  135,    0,  131,    0,    0,    0,    0,    0,  135,
  135,  135,  131,  135,  131,    0,  135,    0,  135,    0,
  135,    0,    0,  135,    0,    0,    0,    0,    0,  131,
  131,    0,    0,    0,  135,  131,  135,    0,    0,  135,
  135,  131,  134,  131,    0,    0,  131,    0,    0,    0,
    0,    0,    0,  133,    0,  133,  133,  133,  133,    0,
    0,    0,    0,    0,    0,    0,  133,    0,    0,  131,
  133,    0,    0,    0,  133,    0,    0,  131,  131,  131,
    0,  131,    0,  133,  131,  133,  131,    0,  131,    0,
    0,  131,    0,    0,    0,    0,    0,    0,    0,  132,
  133,  133,  131,    0,  131,    0,  133,  131,  131,    0,
    0,    0,  133,  154,  133,    0,    0,  133,    0,    0,
    0,   29,    0,   29,   29,   29,   29,    0,    0,    0,
    0,    0,    0,    0,   29,    0,    0,    0,   29,    0,
  133,    0,   29,    0,    0,    0,    0,    0,  133,  133,
  133,   29,  133,   29,    0,  133,    0,  133,    0,  133,
    0,    0,  133,    0,    0,    0,    0,  134,   29,   29,
    0,    0,    0,  133,   29,  133,    0,    0,  133,  133,
   29,   93,   29,    0,    0,   29,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   29,    0,
    0,    0,    0,    0,    0,    0,   29,   29,   29,    0,
   29,    0,    0,   29,    0,   29,    0,   29,    0,    0,
   29,  132,    0,  132,  132,  132,  132,    0,  154,    0,
    0,   29,    0,   29,  132,    0,   29,   29,  132,    0,
    0,    0,  132,    0,    0,    0,    0,    0,    0,    0,
    0,  132,    0,  132,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  132,  132,
    0,    0,    0,    0,  132,    0,    0,    0,    0,    0,
  132,   27,  132,    0,    0,  132,    0,    0,    0,  134,
    0,  134,  134,  134,  134,    0,   93,    0,    0,    0,
    0,    0,  134,    0,    0,    0,  134,    0,  132,    0,
  134,    0,    0,    0,    0,    0,  132,  132,  132,  134,
  132,  134,    0,  132,    0,  132,    0,  132,    0,    0,
  132,    0,    0,    0,    0,    0,  134,  134,    0,    0,
    0,  132,  134,  132,    0,    0,  132,  132,  134,  126,
  134,    0,    0,  134,    0,    0,    0,    0,    0,    0,
  154,    0,  154,  154,  154,  154,    0,    0,    0,    0,
    0,    0,    0,  154,    0,    0,  134,  154,    0,    0,
    0,  154,    0,    0,  134,  134,  134,    0,  134,    0,
  154,  134,  154,  134,    0,  134,    0,    0,  134,    0,
    0,    0,    0,    0,    0,    0,   27,  154,  154,  134,
    0,  134,    0,  154,  134,  134,    0,    0,    0,  154,
   26,  154,    0,    0,  154,    0,    0,    0,   93,    0,
   93,   93,   93,   93,    0,    0,    0,    0,    0,    0,
    0,   93,    0,    0,    0,   93,    0,  154,    0,   93,
    0,    0,    0,    0,    0,  154,  154,  154,   93,  154,
   93,    0,  154,    0,  154,    0,  154,    0,    0,  154,
    0,    0,    0,    0,  126,   93,   93,    0,    0,    0,
  154,   93,  154,    0,    0,  154,  154,   93,  143,   93,
    0,    0,   93,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   93,    0,    0,    0,    0,
    0,    0,    0,   93,   93,   93,    0,   93,    0,    0,
   93,    0,   93,    0,   93,    0,    0,   93,   27,    0,
   27,   27,   27,   27,    0,   26,    0,    0,   93,    0,
   93,   27,    0,   93,   93,   27,    0,    0,    0,   27,
    0,    0,    0,    0,    0,    0,    0,    0,   27,    0,
   27,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   27,   27,    0,    0,    0,
    0,   27,    0,    0,    0,    0,    0,   27,  144,   27,
    0,    0,   27,    0,    0,    0,  126,    0,  126,  126,
  126,  126,    0,  143,    0,    0,    0,    0,    0,  126,
    0,    0,    0,  126,    0,   27,    0,  126,    0,    0,
    0,    0,    0,   27,   27,   27,  126,   27,  126,    0,
   27,    0,   27,    0,   27,    0,    0,   27,    0,    0,
    0,    0,    0,  126,  126,    0,    0,    0,   27,  126,
   27,    0,    0,   27,   27,  126,   28,  126,    0,    0,
  126,    0,    0,    0,    0,    0,    0,   26,    0,   26,
   26,   26,   26,    0,    0,    0,    0,    0,    0,    0,
   26,    0,    0,  126,   26,    0,    0,    0,   26,    0,
    0,  126,  126,  126,    0,  126,    0,   26,  126,   26,
  126,    0,  126,    0,    0,  126,    0,    0,    0,    0,
    0,    0,    0,  144,   26,   26,  126,    0,  126,    0,
   26,  126,  126,    0,    0,    0,   26,  127,   26,    0,
    0,   26,    0,    0,    0,  143,    0,  143,  143,  143,
  143,    0,    0,    0,    0,    0,    0,    0,  143,    0,
    0,    0,  143,    0,   26,    0,  143,    0,    0,    0,
    0,    0,   26,   26,   26,  143,   26,  143,    0,   26,
    0,   26,    0,   26,    0,    0,   26,    0,    0,    0,
    0,   28,  143,  143,    0,    0,    0,   26,  143,   26,
    0,    0,   26,   26,  143,  214,  143,    0,    0,  143,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  143,    0,    0,    0,    0,    0,    0,    0,
  143,  143,  143,    0,  143,    0,    0,  143,    0,  143,
    0,  143,    0,    0,  143,  144,    0,  144,  144,  144,
  144,    0,  127,    0,    0,  143,    0,  143,  144,    0,
  143,  143,  144,    0,    0,    0,  144,    0,    0,  230,
    0,    0,    0,    0,    0,  144,    0,  144,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  144,  144,    0,    0,  205,    0,  144,    0,
    0,    0,    0,    0,  144,    0,  144,    0,    0,  144,
    0,    0,    0,   28,    0,   28,   28,   28,   28,    0,
  214,    0,    0,    0,   40,    0,   28,    0,    0,    0,
   28,    0,  144,    0,   28,    0,  237,    0,    0,    0,
  144,  144,  144,   28,  144,   28,    0,  144,    0,  144,
    0,  144,   45,    0,  144,    0,    0,    0,    0,    0,
   28,   28,  235,    0,    0,  144,   28,  144,    0,    0,
  144,  144,   28,    0,   28,    0,    0,   28,    0,    0,
    0,    0,    0,    0,  127,    0,  127,  127,  127,  127,
    0,    0,    0,    0,  230,    0,    0,  127,    0,    0,
   28,  127,    0,    0,    0,  127,    0,    0,   28,   28,
   28,    0,   28,    0,  127,   28,  127,   28,    0,   28,
    0,  205,   28,    0,    0,    0,    0,    0,    0,    0,
    0,  127,  127,   28,    0,   28,    0,  127,   28,   28,
    0,    0,    0,  127,    0,  127,    0,   40,  127,   40,
    0,    0,  214,    0,  214,  214,  214,  214,    0,    0,
    0,  237,    0,  205,    0,  214,    0,    0,    0,  214,
    0,  127,    0,  214,    0,   45,    0,   45,    0,  127,
  127,  127,  214,  127,  214,    0,  127,  235,  127,    0,
  127,  220,    0,  127,    0,    0,    0,  237,    0,  214,
  214,    0,    0,    0,  127,  214,  127,    0,    0,  127,
  127,  214,    0,  214,    0,    0,  214,    0,    0,    0,
    0,    0,    0,    0,    0,  212,  230,    0,  230,    0,
    0,    0,    0,    0,  239,    0,    0,    0,    0,  214,
    0,    0,    0,  230,    0,    0,   54,  214,  214,  214,
    0,  214,    0,  205,  214,  205,  214,    0,  214,  220,
    0,  214,    0,    0,  230,  230,    0,    0,    0,    0,
  205,    0,  214,  216,  214,    0,    0,  214,  214,  230,
  218,   40,    0,   40,   40,    0,    0,  230,  205,    0,
   40,    0,  214,  237,    0,  237,  230,    0,   40,    0,
  230,    0,  230,    0,    0,    0,  205,  230,  230,   45,
  237,   45,   45,    0,  205,    0,  220,    0,   45,  235,
    0,  235,  237,  205,    0,    0,   45,  205,  230,  205,
    0,    0,    0,    0,  205,  205,  235,    0,    0,    0,
    0,    0,   40,    0,    0,    0,  237,    0,  230,    0,
  212,  230,  230,    0,  237,  205,    0,  235,  235,  239,
    0,    0,   62,    0,   40,    0,  237,    0,    0,    0,
   45,   54,  235,  237,  237,  205,    0,    0,  205,  205,
  235,    0,    0,   40,  220,    0,    0,   61,    0,  235,
    0,    0,   45,    0,    0,  237,   40,   40,  216,    0,
    0,  235,    0,   40,    0,  218,   40,   40,    0,   57,
    0,   45,    0,    0,    0,  237,    0,  214,  237,  237,
  205,  235,  205,    0,   45,   45,    0,    0,    0,    0,
   79,   45,    0,    0,   45,   45,   63,  205,    0,    0,
    0,  235,   81,    0,  235,  235,    0,    0,  220,    0,
  220,    0,    0,    0,  237,    0,  237,    0,    0,    0,
    0,  156,    0,    0,    0,  220,    0,    0,    0,  119,
    0,  237,    0,  205,    0,    0,    0,    0,    0,    0,
    0,  205,  212,    0,  212,    0,    0,   62,    0,    0,
  205,  239,    0,  239,    0,    0,    0,    0,    0,  212,
    0,  220,  205,   54,    0,   54,    0,  237,  239,  220,
    0,    0,   61,    0,    0,  237,  220,    0,  220,    0,
   54,    0,  205,    0,    0,    0,    0,  237,  220,  220,
  216,    0,  216,  220,   57,  212,    0,  218,    0,  218,
    0,    0,  205,  212,  239,  205,  205,  216,    0,  214,
  220,  214,  239,    0,  218,   79,  237,    0,  212,    0,
    0,   63,    0,    0,   54,    0,  214,   81,    0,  220,
  220,    0,    0,  220,  220,    0,  237,  220,    0,  237,
  237,   23,   24,  216,  212,    0,  156,    0,    0,    0,
  218,  216,    0,  239,  119,    0,    0,    0,  218,    0,
    0,    0,  214,    0,  212,   54,    0,  212,  212,    0,
  214,    0,    0,  239,   97,    0,  239,  239,  220,   62,
    0,   62,    0,    0,  116,   54,    0,    0,   54,   54,
    0,    0,  216,    0,    0,    0,   62,    0,  220,  218,
    0,  220,  220,    0,   61,    0,   61,    0,    0,    0,
    0,  214,  216,    0,  172,  216,  216,    0,    0,  218,
    0,   61,  218,  218,    0,    0,   57,    0,   57,    0,
    0,  214,    0,    0,  214,  214,    0,    0,    0,    0,
   62,    0,    0,   57,    0,    0,    0,   79,    0,   79,
    0,    0,    0,   63,    0,   63,    0,    0,    0,   81,
    0,   81,    0,    0,   79,   61,    0,    0,    0,    0,
   63,    0,    0,    0,    0,    0,   81,    0,  156,    0,
  156,   62,    0,    0,    0,    0,  119,   57,  119,    0,
    0,    0,    0,    0,    0,  156,    0,    0,    0,    0,
    0,   62,    0,  119,   62,   62,   61,    0,   79,    0,
    0,    0,    0,    0,   63,    0,    0,    0,    0,    0,
   81,    0,    0,    0,    0,    0,   61,    0,   57,   61,
   61,    0,    0,    0,    0,    0,    0,    0,    0,  156,
    0,    0,    0,    0,    0,    0,    0,  119,   57,   79,
    0,   57,   57,    0,    0,   63,    0,    0,  275,    0,
    0,   81,    0,    0,    0,    0,    0,    0,    0,   79,
    0,    0,   79,   79,    0,   63,    0,    0,   63,   63,
  156,   81,    0,    0,   81,   81,    0,    0,  119,   25,
    0,    0,    0,    0,    0,    0,  299,  300,    0,    0,
  156,    0,    0,  156,  156,    0,    0,    0,  119,    0,
    0,  119,  119,    0,    0,    0,    0,   89,   90,    0,
    0,  316,  317,   25,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  121,    0,    0,  124,    0,    0,
    0,    0,    0,    0,    0,  157,   70,   71,    0,  345,
    0,    0,   72,   73,    0,    0,    0,    0,    0,    0,
   74,    0,   25,    0,   75,  354,  175,  176,    0,  177,
    0,    0,    0,  181,    0,  363,    0,    0,   76,  366,
    0,  117,  117,    0,    0,    0,  367,  117,  117,    0,
    0,    0,    0,    0,    0,  117,    0,   77,    0,  117,
    0,  377,    0,    0,  377,    0,    0,    0,   78,    0,
  385,    0,    0,  117,    0,  213,   25,  390,    0,  390,
    0,    0,  215,  216,   25,    0,    0,  218,    0,  235,
  221,    0,  117,   79,  224,  225,    0,    0,    0,  228,
  230,  232,    0,  117,    0,  228,    0,    0,    0,   80,
    0,    0,  239,   81,  241,    0,   82,    0,    0,    0,
   83,    0,    0,    0,    0,  232,    0,    0,  117,    0,
   18,   19,    0,   20,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  117,    0,    0,    0,  117,    0,
    0,  117,    0,    0,    0,  117,   25,   25,  269,  112,
    0,    0,    0,    0,    0,  117,  117,    0,  117,    0,
    0,    0,  232,    0,  232,    0,  288,    0,    0,    0,
  232,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  294,    0,    0,  296,    0,    0,    0,
    0,  288,    0,    0,    0,    0,    0,    0,    0,   25,
    0,   25,    0,  307,    0,    0,  308,    0,    0,  309,
    0,  312,    0,  315,    0,  128,  129,  130,  131,    0,
  288,  288,    0,    0,    0,    0,  132,  147,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   25,   25,    0,  133,    0,   76,    0,  111,  346,    0,
    0,    0,    0,    0,    0,    0,  350,    0,    0,    0,
  134,  135,    0,    0,    0,    0,  136,    0,    0,    0,
    0,    0,  137,    0,    0,    0,    0,  138,    0,    0,
    0,    0,    0,    0,    0,  112,  112,  112,  112,    0,
    0,    0,   25,    0,    0,    0,  112,    0,    0,   25,
   79,    0,    0,    0,    0,    0,    0,    0,  139,  140,
  141,    0,  142,  112,    0,  112,    0,  143,    0,  144,
    0,    0,  145,    0,    0,    0,    0,  280,    0,    0,
  112,  112,    0,  146,    0,    0,  112,   18,   19,    0,
   20,    0,  112,  112,    0,    0,    0,  112,  112,    0,
    0,    0,    0,    0,  112,  112,    0,    0,    0,    0,
    0,    0,    0,  128,  129,  130,  131,    0,  324,    0,
  112,  112,  112,    0,  132,    0,    0,    0,  112,  112,
  112,    0,  112,  111,  111,  111,  111,  112,  112,  112,
    0,  133,  112,   76,  111,    0,    0,    0,    0,    0,
    0,    0,    0,  112,    0,    0,    0,    0,  134,  135,
    0,  111,    0,  111,  136,    0,    0,    0,    0,    0,
  137,    0,    0,    0,    0,  138,    0,    0,  111,  111,
    0,    0,    0,    0,  111,    0,    0,    0,    0,    0,
  111,    0,    0,    0,    0,  111,    0,    0,   79,    0,
    0,    0,    0,    0,    0,    0,  139,  140,  141,    0,
  142,  128,  129,  130,  131,  143,    0,  144,  111,    0,
  145,    0,  132,    0,    0,    0,  111,  111,  111,    0,
  111,  146,    0,    0,    0,  111,    0,  111,    0,  133,
  111,   76,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  111,  128,  129,  130,  131,  134,  135,    0,    0,
    0,    0,  136,  132,    0,    0,    0,    0,  137,    0,
    0,    0,    0,  138,    0,    0,    0,    0,    0,    0,
  133,    0,   76,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   79,  134,  135,    0,
    0,    0,    0,  136,  139,  140,  141,    0,  142,  137,
    0,    0,    0,  143,  138,  144,    0,    0,  145,    0,
  128,  129,  130,  131,    0,    0,    0,    0,    0,  146,
    0,  132,    0,    0,    0,    0,    0,   79,    0,    0,
    0,    0,    0,    0,    0,  139,  140,  141,  133,  142,
   76,    0,    0,    0,  143,    0,  144,    0,    0,  145,
    0,  128,  129,  130,  131,  134,  135,    0,    0,    0,
  146,  136,  132,    0,    0,    0,    0,  137,    0,    0,
    0,    0,  138,    0,    0,    0,    0,    0,    0,  133,
    0,   76,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   79,  134,  135,    0,    0,
    0,    0,  136,  139,  140,  141,    0,  142,  137,    0,
    0,    0,  143,  138,  144,    0,    0,  145,    0,    0,
    0,    0,    0,   31,    0,    0,    0,    0,  146,    0,
    0,    0,   18,   19,   32,   20,   79,    0,    0,    0,
   33,   34,    0,    0,  139,  140,  141,    0,  142,    0,
   35,   36,    0,  143,    0,  144,    0,    0,  145,    0,
    0,    0,    0,    0,   37,    0,    0,    0,    0,  146,
    0,   38,   39,   40,    0,    0,    0,    0,   41,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   42,    0,    0,   43,    0,    0,    0,    0,    0,   44,
    0,    0,    0,    0,    0,    0,   45,   46,   47,   48,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   49,    0,    0,   50,    0,    0,    0,
    0,    0,    0,   51,
};
static const short yycheck[] = {                         43,
    0,   60,  123,   62,   43,  123,   43,   43,  250,  275,
  123,    4,   59,   35,   36,  123,  125,   80,  123,   43,
   69,   61,   44,  236,   46,   47,   48,  281,   50,  174,
  266,   53,   60,  156,   62,  280,  151,  334,  342,   61,
  287,   41,  267,  268,  269,   38,  335,  264,  286,  303,
  123,  273,  123,  291,  279,  272,  294,  180,  359,   28,
  361,  372,   60,  310,   62,  123,  355,  327,  372,  380,
  324,  325,  383,  336,  385,    0,  298,  380,  379,  339,
  383,   61,  385,  380,   77,  302,  383,   56,  385,  286,
  312,  206,  207,  208,  291,  240,  334,  294,  343,  372,
  373,  323,  247,  357,  340,  168,  229,  170,  171,  123,
   61,  324,  161,  160,   43,  381,  382,  123,  384,  261,
  262,  263,  376,  123,  378,  125,  166,  284,  370,  123,
  290,  381,  382,  123,  384,  307,  304,  305,  131,  125,
  358,  259,  260,  125,  166,  370,  139,  311,  316,  317,
  125,  259,  260,  321,  322,  259,  260,    0,  266,  278,
  328,  329,  344,  125,  295,  296,    0,  304,  305,  299,
  300,  259,  260,  125,  299,  300,  223,  345,  346,  316,
  317,  344,  125,  310,  321,  322,  125,  311,  259,  260,
  125,  328,  329,  355,  362,  311,  297,  347,  369,   40,
  125,  342,  372,  372,  372,  373,  338,  274,  345,  346,
  380,  381,  382,  383,  384,  385,  330,  274,  211,  212,
  331,  125,  244,   44,   41,  362,  333,  337,   44,  288,
  342,   41,  340,  380,  381,  382,  383,  384,  385,  235,
  277,  358,  289,   68,   30,  127,  108,  376,  388,  355,
  329,  372,  373,  356,  372,  373,  358,  257,  355,  259,
  260,  261,  262,  355,  372,  373,  266,  326,  381,  382,
  270,  384,  381,  382,  274,  384,  381,  382,  278,  384,
   64,  309,  125,   54,  284,  365,  327,  287,  310,  289,
  266,  125,  300,    0,  112,  295,  296,  297,   64,  299,
  300,  372,  373,  325,  304,  305,  284,  307,  381,  382,
  310,  384,  305,  306,   -1,   -1,  316,  317,  318,   -1,
   -1,  321,  322,  381,  382,  369,  384,  327,  328,  329,
  330,  331,  257,  333,  259,  374,  372,  337,  338,  339,
  340,   -1,  342,    0,  344,  345,  346,  347,   -1,  274,
  374,   -1,  352,  353,  354,  123,  356,  381,  382,  359,
  384,  361,  362,  363,  357,  290,  366,  381,  382,  369,
  384,  364,  372,  373,   -1,  381,  382,  377,  384,  379,
   -1,  381,  382,  383,  384,  310,  311,  381,  382,   -1,
  384,  381,  382,  318,  384,  381,  382,   -1,  384,  381,
  382,   -1,  384,    0,   -1,  330,  381,  382,   -1,  384,
   -1,   -1,  337,  338,  257,   -1,  259,   -1,  125,  381,
  382,   -1,  384,  257,   -1,  259,  260,  261,  262,  381,
  382,  274,  384,  123,  359,   -1,  270,   -1,  381,  382,
  274,  384,  381,  382,  278,  384,  381,  382,   -1,  384,
   -1,   -1,   -1,  287,  379,  289,  381,  382,  383,  384,
   -1,  295,  296,  297,   -1,  299,  300,  310,  125,   -1,
  304,  305,   -1,   -1,   -1,  318,  310,  381,  382,  123,
  384,   -1,  316,   -1,  318,   -1,   -1,  321,  331,   -1,
  333,  259,  260,  327,   -1,  338,  330,  331,  266,  333,
   -1,   -1,   -1,  337,  338,  339,   -1,   -1,  342,   -1,
  344,   -1,   -1,    0,   -1,   -1,  359,   -1,  352,  353,
  354,   -1,  356,   -1,   -1,  359,   -1,  361,  125,  363,
   -1,   -1,  366,   -1,   -1,  369,  379,   -1,  372,  382,
  383,   -1,   -1,  377,   -1,  379,   -1,   -1,  382,  383,
  257,   -1,  259,  260,  261,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  270,   -1,   -1,   -1,  274,   -1,  259,
  260,  278,  340,   -1,   -1,   -1,  266,   -1,  125,   -1,
  287,   -1,  289,   -1,   -1,   -1,   -1,   -1,  295,  296,
    0,   -1,  299,  300,   -1,   -1,   -1,  304,  305,   -1,
  257,   -1,  259,  310,  372,  373,   -1,   -1,   -1,  316,
   -1,  318,   -1,   -1,  321,  259,  260,  274,   -1,   -1,
  327,   -1,  266,  330,  331,   -1,  333,    0,   -1,   -1,
  337,  338,  339,   -1,   -1,   -1,   -1,  344,  125,   -1,
   -1,   -1,   -1,   -1,   -1,  352,  353,  354,   -1,  356,
  340,   -1,  359,  310,  361,   -1,  363,   -1,   -1,  366,
  257,  318,  259,  260,  261,  262,   -1,   -1,   -1,   -1,
  377,   -1,  379,  270,   -1,  382,  383,  274,   -1,   -1,
  337,  278,  372,  373,   -1,   -1,   -1,   -1,   -1,   -1,
  287,   -1,  289,   -1,   -1,   -1,  340,   -1,  295,  296,
   -1,   -1,  359,   -1,   -1,  123,   -1,  304,  305,   -1,
  257,   -1,  259,  310,   -1,  125,   -1,  123,   -1,  316,
   -1,  318,  379,   -1,  321,  382,  383,  274,  372,  373,
   -1,   -1,   -1,   -1,  331,   -1,  333,    0,   -1,   -1,
   -1,  338,   -1,   -1,   -1,   -1,   -1,  344,   -1,   -1,
   -1,   -1,  125,   -1,   -1,  352,  353,  354,   -1,  356,
   -1,   -1,  359,   -1,  361,   -1,  363,   -1,   -1,  366,
  257,  318,  259,  260,  261,  262,   -1,   -1,   -1,   -1,
  377,   -1,  379,  270,   -1,  382,  383,  274,   -1,   -1,
   -1,  278,   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,
  287,   -1,  289,   -1,   -1,    0,   -1,   -1,   -1,  316,
  317,   -1,  359,   -1,  321,  322,   -1,  304,  305,   -1,
   -1,  328,  329,  310,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  379,   -1,  321,  382,  383,   -1,  345,  346,
   -1,  259,  260,   -1,  331,   -1,  333,  257,  266,  259,
   -1,  338,   -1,  259,  260,  362,   -1,  344,   -1,   -1,
  266,   -1,  125,   -1,  274,  352,  353,  354,   -1,  356,
   -1,   -1,  359,   -1,  361,   -1,  363,   -1,   -1,  366,
   -1,   -1,   -1,   -1,  257,   -1,  259,  260,  261,  262,
  377,   -1,  379,   -1,   -1,  382,  383,  270,   -1,   -1,
  310,  274,   -1,   -1,   -1,  278,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,  287,   -1,  289,  327,   -1,    0,
  330,   -1,  340,   -1,   -1,   -1,   -1,  337,  338,  339,
  125,  304,  305,   -1,  340,    0,   -1,  310,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,   -1,   -1,  321,  359,
   -1,   -1,   -1,   -1,  372,  373,   -1,   -1,  331,   -1,
  333,   -1,   -1,   -1,   -1,  338,  372,  373,   -1,  379,
   -1,  344,  382,  383,   -1,   -1,   -1,   -1,   -1,  352,
  353,  354,   -1,  356,   -1,   -1,  359,    0,  361,   -1,
  363,   -1,   -1,  366,  257,   -1,  259,  260,  261,  262,
   -1,   -1,   -1,   -1,  377,   -1,  379,  270,   -1,  382,
  383,  274,   -1,   -1,   -1,  278,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  287,   -1,  289,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  304,  305,   -1,  125,   -1,   -1,  310,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,   -1,   -1,  321,   -1,
  125,   -1,  257,   -1,  259,  260,  261,  262,  331,   -1,
  333,   -1,   -1,   -1,   -1,  270,   -1,   -1,   -1,  274,
   -1,  344,   -1,  278,   -1,   -1,   -1,   -1,   -1,  352,
  353,  354,  287,  356,  289,   -1,  359,    0,  361,   -1,
  363,   -1,   -1,  366,   -1,   -1,   -1,   -1,   -1,  304,
  305,   -1,  125,   -1,  377,  310,  379,   -1,   -1,  382,
  383,  316,   -1,  318,   -1,   -1,  321,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  344,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  352,  353,  354,
   -1,  356,   -1,   -1,  359,    0,  361,   -1,  363,   -1,
   -1,  366,   -1,   -1,  369,   -1,  257,   -1,  259,  260,
  261,  262,  377,   -1,  379,   -1,   -1,  382,  383,  270,
   -1,   -1,  257,  274,  259,   -1,   -1,  278,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  287,   -1,  289,  274,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  125,  304,  305,   -1,   -1,   -1,   -1,  310,
   -1,   -1,   -1,   -1,   -1,  316,    0,  318,   -1,   -1,
  321,   -1,   -1,   -1,  257,  310,  259,  260,  261,  262,
   -1,   -1,   -1,  318,   -1,   -1,   -1,  270,   -1,   -1,
   -1,  274,   -1,  344,   -1,  278,  331,   -1,  333,   -1,
   -1,  352,  353,  354,  287,  356,  289,   -1,  359,   -1,
  361,   -1,  363,   -1,   -1,  366,   -1,   -1,  369,   -1,
  125,  304,  305,   -1,  359,   -1,  377,  310,  379,   -1,
   -1,  382,  383,  316,    0,  318,   -1,   -1,  321,   -1,
   -1,   -1,   -1,   -1,  379,   -1,   -1,  382,  383,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  344,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  352,
  353,  354,   -1,  356,   -1,   -1,  359,   -1,  361,   -1,
  363,   -1,   -1,  366,  257,   -1,  259,  260,  261,  262,
   -1,  125,   -1,   -1,  377,   -1,  379,  270,   -1,  382,
  383,  274,   -1,   -1,   -1,  278,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  287,   -1,  289,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  304,  305,   -1,   -1,   -1,   -1,  310,   -1,   -1,
   -1,   -1,   -1,  316,    0,  318,   -1,   -1,  321,   -1,
   -1,   -1,  257,   -1,  259,  260,  261,  262,   -1,  125,
   -1,   -1,   -1,   -1,   -1,  270,   -1,   -1,   -1,  274,
   -1,  344,   -1,  278,   -1,   -1,   -1,   -1,   -1,  352,
  353,  354,  287,  356,  289,   -1,  359,   -1,  361,   -1,
  363,   -1,   -1,  366,   -1,   -1,   -1,   -1,   -1,  304,
  305,   -1,   -1,   -1,  377,  310,  379,   -1,   -1,  382,
  383,  316,    0,  318,   -1,   -1,  321,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,  260,  261,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  270,   -1,   -1,  344,
  274,   -1,   -1,   -1,  278,   -1,   -1,  352,  353,  354,
   -1,  356,   -1,  287,  359,  289,  361,   -1,  363,   -1,
   -1,  366,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  125,
  304,  305,  377,   -1,  379,   -1,  310,  382,  383,   -1,
   -1,   -1,  316,    0,  318,   -1,   -1,  321,   -1,   -1,
   -1,  257,   -1,  259,  260,  261,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  270,   -1,   -1,   -1,  274,   -1,
  344,   -1,  278,   -1,   -1,   -1,   -1,   -1,  352,  353,
  354,  287,  356,  289,   -1,  359,   -1,  361,   -1,  363,
   -1,   -1,  366,   -1,   -1,   -1,   -1,  125,  304,  305,
   -1,   -1,   -1,  377,  310,  379,   -1,   -1,  382,  383,
  316,    0,  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  344,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  352,  353,  354,   -1,
  356,   -1,   -1,  359,   -1,  361,   -1,  363,   -1,   -1,
  366,  257,   -1,  259,  260,  261,  262,   -1,  125,   -1,
   -1,  377,   -1,  379,  270,   -1,  382,  383,  274,   -1,
   -1,   -1,  278,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  287,   -1,  289,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  304,  305,
   -1,   -1,   -1,   -1,  310,   -1,   -1,   -1,   -1,   -1,
  316,    0,  318,   -1,   -1,  321,   -1,   -1,   -1,  257,
   -1,  259,  260,  261,  262,   -1,  125,   -1,   -1,   -1,
   -1,   -1,  270,   -1,   -1,   -1,  274,   -1,  344,   -1,
  278,   -1,   -1,   -1,   -1,   -1,  352,  353,  354,  287,
  356,  289,   -1,  359,   -1,  361,   -1,  363,   -1,   -1,
  366,   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,
   -1,  377,  310,  379,   -1,   -1,  382,  383,  316,    0,
  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,  260,  261,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  270,   -1,   -1,  344,  274,   -1,   -1,
   -1,  278,   -1,   -1,  352,  353,  354,   -1,  356,   -1,
  287,  359,  289,  361,   -1,  363,   -1,   -1,  366,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  125,  304,  305,  377,
   -1,  379,   -1,  310,  382,  383,   -1,   -1,   -1,  316,
    0,  318,   -1,   -1,  321,   -1,   -1,   -1,  257,   -1,
  259,  260,  261,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  270,   -1,   -1,   -1,  274,   -1,  344,   -1,  278,
   -1,   -1,   -1,   -1,   -1,  352,  353,  354,  287,  356,
  289,   -1,  359,   -1,  361,   -1,  363,   -1,   -1,  366,
   -1,   -1,   -1,   -1,  125,  304,  305,   -1,   -1,   -1,
  377,  310,  379,   -1,   -1,  382,  383,  316,    0,  318,
   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  344,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  352,  353,  354,   -1,  356,   -1,   -1,
  359,   -1,  361,   -1,  363,   -1,   -1,  366,  257,   -1,
  259,  260,  261,  262,   -1,  125,   -1,   -1,  377,   -1,
  379,  270,   -1,  382,  383,  274,   -1,   -1,   -1,  278,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  287,   -1,
  289,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,  310,   -1,   -1,   -1,   -1,   -1,  316,    0,  318,
   -1,   -1,  321,   -1,   -1,   -1,  257,   -1,  259,  260,
  261,  262,   -1,  125,   -1,   -1,   -1,   -1,   -1,  270,
   -1,   -1,   -1,  274,   -1,  344,   -1,  278,   -1,   -1,
   -1,   -1,   -1,  352,  353,  354,  287,  356,  289,   -1,
  359,   -1,  361,   -1,  363,   -1,   -1,  366,   -1,   -1,
   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,  377,  310,
  379,   -1,   -1,  382,  383,  316,    0,  318,   -1,   -1,
  321,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
  260,  261,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  270,   -1,   -1,  344,  274,   -1,   -1,   -1,  278,   -1,
   -1,  352,  353,  354,   -1,  356,   -1,  287,  359,  289,
  361,   -1,  363,   -1,   -1,  366,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  125,  304,  305,  377,   -1,  379,   -1,
  310,  382,  383,   -1,   -1,   -1,  316,    0,  318,   -1,
   -1,  321,   -1,   -1,   -1,  257,   -1,  259,  260,  261,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  270,   -1,
   -1,   -1,  274,   -1,  344,   -1,  278,   -1,   -1,   -1,
   -1,   -1,  352,  353,  354,  287,  356,  289,   -1,  359,
   -1,  361,   -1,  363,   -1,   -1,  366,   -1,   -1,   -1,
   -1,  125,  304,  305,   -1,   -1,   -1,  377,  310,  379,
   -1,   -1,  382,  383,  316,    0,  318,   -1,   -1,  321,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  344,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  352,  353,  354,   -1,  356,   -1,   -1,  359,   -1,  361,
   -1,  363,   -1,   -1,  366,  257,   -1,  259,  260,  261,
  262,   -1,  125,   -1,   -1,  377,   -1,  379,  270,   -1,
  382,  383,  274,   -1,   -1,   -1,  278,   -1,   -1,    0,
   -1,   -1,   -1,   -1,   -1,  287,   -1,  289,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  304,  305,   -1,   -1,    0,   -1,  310,   -1,
   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,   -1,  321,
   -1,   -1,   -1,  257,   -1,  259,  260,  261,  262,   -1,
  125,   -1,   -1,   -1,    0,   -1,  270,   -1,   -1,   -1,
  274,   -1,  344,   -1,  278,   -1,    0,   -1,   -1,   -1,
  352,  353,  354,  287,  356,  289,   -1,  359,   -1,  361,
   -1,  363,    0,   -1,  366,   -1,   -1,   -1,   -1,   -1,
  304,  305,    0,   -1,   -1,  377,  310,  379,   -1,   -1,
  382,  383,  316,   -1,  318,   -1,   -1,  321,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,  260,  261,  262,
   -1,   -1,   -1,   -1,  125,   -1,   -1,  270,   -1,   -1,
  344,  274,   -1,   -1,   -1,  278,   -1,   -1,  352,  353,
  354,   -1,  356,   -1,  287,  359,  289,  361,   -1,  363,
   -1,  125,  366,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  304,  305,  377,   -1,  379,   -1,  310,  382,  383,
   -1,   -1,   -1,  316,   -1,  318,   -1,  123,  321,  125,
   -1,   -1,  257,   -1,  259,  260,  261,  262,   -1,   -1,
   -1,  125,   -1,    0,   -1,  270,   -1,   -1,   -1,  274,
   -1,  344,   -1,  278,   -1,  123,   -1,  125,   -1,  352,
  353,  354,  287,  356,  289,   -1,  359,  125,  361,   -1,
  363,    0,   -1,  366,   -1,   -1,   -1,    0,   -1,  304,
  305,   -1,   -1,   -1,  377,  310,  379,   -1,   -1,  382,
  383,  316,   -1,  318,   -1,   -1,  321,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,    0,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,  344,
   -1,   -1,   -1,  274,   -1,   -1,    0,  352,  353,  354,
   -1,  356,   -1,  257,  359,  259,  361,   -1,  363,    0,
   -1,  366,   -1,   -1,  295,  296,   -1,   -1,   -1,   -1,
  274,   -1,  377,    0,  379,   -1,   -1,  382,  383,  310,
    0,  257,   -1,  259,  260,   -1,   -1,  318,  125,   -1,
  266,   -1,    0,  257,   -1,  259,  327,   -1,  274,   -1,
  331,   -1,  333,   -1,   -1,   -1,  310,  338,  339,  257,
  274,  259,  260,   -1,  318,   -1,  125,   -1,  266,  257,
   -1,  259,  125,  327,   -1,   -1,  274,  331,  359,  333,
   -1,   -1,   -1,   -1,  338,  339,  274,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,  310,   -1,  379,   -1,
  125,  382,  383,   -1,  318,  359,   -1,  295,  296,  125,
   -1,   -1,    0,   -1,  340,   -1,  330,   -1,   -1,   -1,
  318,  125,  310,  337,  338,  379,   -1,   -1,  382,  383,
  318,   -1,   -1,  359,  125,   -1,   -1,    0,   -1,  327,
   -1,   -1,  340,   -1,   -1,  359,  372,  373,  125,   -1,
   -1,  339,   -1,  379,   -1,  125,  382,  383,   -1,    0,
   -1,  359,   -1,   -1,   -1,  379,   -1,  125,  382,  383,
  257,  359,  259,   -1,  372,  373,   -1,   -1,   -1,   -1,
    0,  379,   -1,   -1,  382,  383,    0,  274,   -1,   -1,
   -1,  379,    0,   -1,  382,  383,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,    0,   -1,   -1,   -1,  274,   -1,   -1,   -1,    0,
   -1,  274,   -1,  310,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,  257,   -1,  259,   -1,   -1,  125,   -1,   -1,
  327,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  274,
   -1,  310,  339,  257,   -1,  259,   -1,  310,  274,  318,
   -1,   -1,  125,   -1,   -1,  318,  257,   -1,  259,   -1,
  274,   -1,  359,   -1,   -1,   -1,   -1,  330,  337,  338,
  257,   -1,  259,  274,  125,  310,   -1,  257,   -1,  259,
   -1,   -1,  379,  318,  310,  382,  383,  274,   -1,  257,
  359,  259,  318,   -1,  274,  125,  359,   -1,  333,   -1,
   -1,  125,   -1,   -1,  318,   -1,  274,  125,   -1,  310,
  379,   -1,   -1,  382,  383,   -1,  379,  318,   -1,  382,
  383,    2,    3,  310,  359,   -1,  125,   -1,   -1,   -1,
  310,  318,   -1,  359,  125,   -1,   -1,   -1,  318,   -1,
   -1,   -1,  310,   -1,  379,  359,   -1,  382,  383,   -1,
  318,   -1,   -1,  379,   35,   -1,  382,  383,  359,  257,
   -1,  259,   -1,   -1,   45,  379,   -1,   -1,  382,  383,
   -1,   -1,  359,   -1,   -1,   -1,  274,   -1,  379,  359,
   -1,  382,  383,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,  359,  379,   -1,   75,  382,  383,   -1,   -1,  379,
   -1,  274,  382,  383,   -1,   -1,  257,   -1,  259,   -1,
   -1,  379,   -1,   -1,  382,  383,   -1,   -1,   -1,   -1,
  318,   -1,   -1,  274,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  274,  318,   -1,   -1,   -1,   -1,
  274,   -1,   -1,   -1,   -1,   -1,  274,   -1,  257,   -1,
  259,  359,   -1,   -1,   -1,   -1,  257,  318,  259,   -1,
   -1,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
   -1,  379,   -1,  274,  382,  383,  359,   -1,  318,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,  379,   -1,  359,  382,
  383,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,  379,  359,
   -1,  382,  383,   -1,   -1,  359,   -1,   -1,  219,   -1,
   -1,  359,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  379,
   -1,   -1,  382,  383,   -1,  379,   -1,   -1,  382,  383,
  359,  379,   -1,   -1,  382,  383,   -1,   -1,  359,    4,
   -1,   -1,   -1,   -1,   -1,   -1,  257,  258,   -1,   -1,
  379,   -1,   -1,  382,  383,   -1,   -1,   -1,  379,   -1,
   -1,  382,  383,   -1,   -1,   -1,   -1,   32,   33,   -1,
   -1,  282,  283,   38,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   49,   -1,   -1,   52,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   60,  257,  258,   -1,  310,
   -1,   -1,  263,  264,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   77,   -1,  275,  326,   81,   82,   -1,   84,
   -1,   -1,   -1,   88,   -1,  336,   -1,   -1,  289,  340,
   -1,  257,  258,   -1,   -1,   -1,  347,  263,  264,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,  308,   -1,  275,
   -1,  362,   -1,   -1,  365,   -1,   -1,   -1,  319,   -1,
  371,   -1,   -1,  289,   -1,  130,  131,  378,   -1,  380,
   -1,   -1,  137,  138,  139,   -1,   -1,  142,   -1,  123,
  145,   -1,  308,  344,  149,  150,   -1,   -1,   -1,  154,
  155,  156,   -1,  319,   -1,  160,   -1,   -1,   -1,  360,
   -1,   -1,  167,  364,  169,   -1,  367,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  180,   -1,   -1,  344,   -1,
  381,  382,   -1,  384,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  360,   -1,   -1,   -1,  364,   -1,
   -1,  367,   -1,   -1,   -1,  371,  211,  212,  213,  123,
   -1,   -1,   -1,   -1,   -1,  381,  382,   -1,  384,   -1,
   -1,   -1,  227,   -1,  229,   -1,  231,   -1,   -1,   -1,
  235,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  248,   -1,   -1,  251,   -1,   -1,   -1,
   -1,  256,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  264,
   -1,  266,   -1,  268,   -1,   -1,  271,   -1,   -1,  274,
   -1,  276,   -1,  278,   -1,  259,  260,  261,  262,   -1,
  285,  286,   -1,   -1,   -1,   -1,  270,  123,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  305,  306,   -1,  287,   -1,  289,   -1,  123,  313,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  321,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,  310,   -1,   -1,   -1,
   -1,   -1,  316,   -1,   -1,   -1,   -1,  321,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  259,  260,  261,  262,   -1,
   -1,   -1,  357,   -1,   -1,   -1,  270,   -1,   -1,  364,
  344,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  352,  353,
  354,   -1,  356,  287,   -1,  289,   -1,  361,   -1,  363,
   -1,   -1,  366,   -1,   -1,   -1,   -1,  125,   -1,   -1,
  304,  305,   -1,  377,   -1,   -1,  310,  381,  382,   -1,
  384,   -1,  316,  317,   -1,   -1,   -1,  321,  322,   -1,
   -1,   -1,   -1,   -1,  328,  329,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  259,  260,  261,  262,   -1,  125,   -1,
  344,  345,  346,   -1,  270,   -1,   -1,   -1,  352,  353,
  354,   -1,  356,  259,  260,  261,  262,  361,  362,  363,
   -1,  287,  366,  289,  270,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  377,   -1,   -1,   -1,   -1,  304,  305,
   -1,  287,   -1,  289,  310,   -1,   -1,   -1,   -1,   -1,
  316,   -1,   -1,   -1,   -1,  321,   -1,   -1,  304,  305,
   -1,   -1,   -1,   -1,  310,   -1,   -1,   -1,   -1,   -1,
  316,   -1,   -1,   -1,   -1,  321,   -1,   -1,  344,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  352,  353,  354,   -1,
  356,  259,  260,  261,  262,  361,   -1,  363,  344,   -1,
  366,   -1,  270,   -1,   -1,   -1,  352,  353,  354,   -1,
  356,  377,   -1,   -1,   -1,  361,   -1,  363,   -1,  287,
  366,  289,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  377,  259,  260,  261,  262,  304,  305,   -1,   -1,
   -1,   -1,  310,  270,   -1,   -1,   -1,   -1,  316,   -1,
   -1,   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,   -1,
  287,   -1,  289,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  344,  304,  305,   -1,
   -1,   -1,   -1,  310,  352,  353,  354,   -1,  356,  316,
   -1,   -1,   -1,  361,  321,  363,   -1,   -1,  366,   -1,
  259,  260,  261,  262,   -1,   -1,   -1,   -1,   -1,  377,
   -1,  270,   -1,   -1,   -1,   -1,   -1,  344,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  352,  353,  354,  287,  356,
  289,   -1,   -1,   -1,  361,   -1,  363,   -1,   -1,  366,
   -1,  259,  260,  261,  262,  304,  305,   -1,   -1,   -1,
  377,  310,  270,   -1,   -1,   -1,   -1,  316,   -1,   -1,
   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,   -1,  287,
   -1,  289,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  344,  304,  305,   -1,   -1,
   -1,   -1,  310,  352,  353,  354,   -1,  356,  316,   -1,
   -1,   -1,  361,  321,  363,   -1,   -1,  366,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,   -1,   -1,  377,   -1,
   -1,   -1,  381,  382,  276,  384,  344,   -1,   -1,   -1,
  282,  283,   -1,   -1,  352,  353,  354,   -1,  356,   -1,
  292,  293,   -1,  361,   -1,  363,   -1,   -1,  366,   -1,
   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,   -1,  377,
   -1,  313,  314,  315,   -1,   -1,   -1,   -1,  320,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  332,   -1,   -1,  335,   -1,   -1,   -1,   -1,   -1,  341,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  365,   -1,   -1,  368,   -1,   -1,   -1,
   -1,   -1,   -1,  375,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 385
#if YYDEBUG
static const char *yyname[] = {

"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,"'('","')'",0,"'+'","','",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'<'","'='",
"'>'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,"TOKACCOUNT","TOKACCOUNTS","TOKACTION","TOKACTIONS","TOKADDHEADER",
"TOKADDTOCACHE","TOKAGE","TOKALL","TOKALLOWMANY","TOKAND","TOKANYNAME",
"TOKANYSIZE","TOKANYTYPE","TOKAPPEND","TOKATTACHMENT","TOKBODY","TOKBYTES",
"TOKCACHE","TOKCASE","TOKCMDUSER","TOKCOMPRESS","TOKCONTINUE","TOKCOUNT",
"TOKCOURIER","TOKDAYS","TOKDEFUSER","TOKDELTOOBIG","TOKDISABLED","TOKDOMAIN",
"TOKDOTLOCK","TOKDROP","TOKEQ","TOKEXEC","TOKEXPIRE","TOKFCNTL","TOKFILEGROUP",
"TOKFILEUMASK","TOKFLOCK","TOKFOLDER","TOKFOLDERS","TOKFROM","TOKGIGABYTES",
"TOKGROUP","TOKGROUPS","TOKHEADER","TOKHEADERS","TOKHOURS","TOKIMAP","TOKIMAPS",
"TOKIMPLACT","TOKIN","TOKINCACHE","TOKINVALID","TOKKEEP","TOKKEY",
"TOKKILOBYTES","TOKLOCKFILE","TOKLOCKTYPES","TOKLOOKUPORDER","TOKMAILDIR",
"TOKMAILDIRS","TOKMATCH","TOKMATCHED","TOKMAXSIZE","TOKMBOX","TOKMBOXES",
"TOKMEGABYTES","TOKMINUTES","TOKMONTHS","TOKNE","TOKNEWONLY","TOKNNTP",
"TOKNNTPS","TOKNOAPOP","TOKNOCRAMMD5","TOKNOCREATE","TOKNOLOGIN","TOKNONE",
"TOKNORECEIVED","TOKNOT","TOKNOUIDL","TOKNOVERIFY","TOKOLDONLY","TOKOR",
"TOKPARALLELACCOUNTS","TOKPASS","TOKPASSWD","TOKPIPE","TOKPOP3","TOKPOP3S",
"TOKPORT","TOKPROXY","TOKPURGEAFTER","TOKQUEUEHIGH","TOKQUEUELOW",
"TOKREMOVEFROMCACHE","TOKREMOVEHEADER","TOKREMOVEHEADERS","TOKRETURNS",
"TOKREWRITE","TOKSECONDS","TOKSERVER","TOKSET","TOKSIZE","TOKSMTP","TOKSTDIN",
"TOKSTDOUT","TOKSTRING","TOKSTRIPCHARACTERS","TOKTAG","TOKTAGGED","TOKTIMEOUT",
"TOKTO","TOKTOTALSIZE","TOKUNMATCHED","TOKUSER","TOKUSERS","TOKVALUE",
"TOKVERIFYCERTS","TOKWEEKS","TOKWRITE","TOKYEARS","NONE","NUMBER","STRING",
"STRMACRO","NUMMACRO","STRCOMMAND","NUMCOMMAND",
};
static const char *yyrule[] = {
"$accept : cmds",
"cmds :",
"cmds : cmds account",
"cmds : cmds defaction",
"cmds : cmds defmacro",
"cmds : cmds rule",
"cmds : cmds set",
"cmds : cmds close",
"cmds : cmds cache",
"cmds : cmds NONE",
"actionp : TOKACTION",
"actionp : TOKACTIONS",
"userp : TOKUSER",
"userp : TOKUSERS",
"accountp : TOKACCOUNT",
"accountp : TOKACCOUNTS",
"groupp : TOKGROUP",
"groupp : TOKGROUPS",
"folderp : TOKFOLDER",
"folderp : TOKFOLDERS",
"maildirp : TOKMAILDIR",
"maildirp : TOKMAILDIRS",
"mboxp : TOKMBOX",
"mboxp : TOKMBOXES",
"rmheaderp : TOKREMOVEHEADER",
"rmheaderp : TOKREMOVEHEADERS",
"val : TOKVALUE strv",
"val : strv",
"optval : TOKVALUE strv",
"optval :",
"xstrv : STRCOMMAND",
"xstrv : STRING",
"xstrv : STRMACRO",
"strv : xstrv",
"strv : strv '+' xstrv",
"numv : NUMCOMMAND",
"numv : NUMBER",
"numv : NUMMACRO",
"replstrv : strv",
"replpathv : strv",
"size : numv",
"size : numv TOKBYTES",
"size : numv TOKKILOBYTES",
"size : numv TOKMEGABYTES",
"size : numv TOKGIGABYTES",
"time : numv",
"time : numv TOKHOURS",
"time : numv TOKMINUTES",
"time : numv TOKSECONDS",
"time : numv TOKDAYS",
"time : numv TOKWEEKS",
"time : numv TOKMONTHS",
"time : numv TOKYEARS",
"expire : TOKEXPIRE time",
"expire :",
"cache : TOKCACHE replpathv expire",
"set : TOKSET TOKMAXSIZE size",
"set : TOKSET TOKLOCKTYPES locklist",
"set : TOKSET TOKLOCKFILE replpathv",
"set : TOKSET TOKDELTOOBIG",
"set : TOKSET TOKALLOWMANY",
"set : TOKSET TOKDEFUSER strv",
"set : TOKSET TOKCMDUSER strv",
"set : TOKSET TOKSTRIPCHARACTERS strv",
"set : TOKSET TOKTIMEOUT time",
"set : TOKSET TOKQUEUEHIGH numv",
"set : TOKSET TOKQUEUELOW numv",
"set : TOKSET TOKPARALLELACCOUNTS numv",
"set : TOKSET TOKPROXY replstrv",
"set : TOKSET TOKVERIFYCERTS",
"set : TOKSET TOKIMPLACT TOKKEEP",
"set : TOKSET TOKIMPLACT TOKDROP",
"set : TOKSET TOKPURGEAFTER numv",
"set : TOKSET TOKPURGEAFTER TOKNONE",
"set : TOKSET TOKNORECEIVED",
"set : TOKSET TOKNOCREATE",
"set : TOKSET TOKFILEGROUP TOKUSER",
"set : TOKSET TOKFILEGROUP localgid",
"set : TOKSET TOKFILEUMASK TOKUSER",
"set : TOKSET TOKLOOKUPORDER ufnlist",
"set : TOKSET TOKFILEUMASK numv",
"defmacro : STRMACRO '=' strv",
"defmacro : NUMMACRO '=' numv",
"replstrslist : replstrslist strv",
"replstrslist : strv",
"stringslist : stringslist replstrv",
"stringslist : replstrv",
"pathslist : pathslist replpathv",
"pathslist : replpathv",
"ufn : TOKPASSWD",
"ufn : TOKCOURIER",
"ufnlist : ufnlist ufn",
"ufnlist : ufn",
"rmheaders : rmheaderp strv",
"rmheaders : rmheaderp '{' replstrslist '}'",
"maildirs : maildirp replpathv",
"maildirs : maildirp '{' pathslist '}'",
"mboxes : mboxp replpathv",
"mboxes : mboxp '{' pathslist '}'",
"folders : folderp replstrv",
"folders : folderp '{' stringslist '}'",
"lock : TOKFCNTL",
"lock : TOKFLOCK",
"lock : TOKDOTLOCK",
"locklist : locklist lock",
"locklist : lock",
"locklist : TOKNONE",
"localgid : replstrv",
"localgid : numv",
"user :",
"user : TOKUSER strv",
"users :",
"users : userp strv",
"users : userp '{' replstrslist '}'",
"casere : TOKCASE replstrv",
"casere : replstrv",
"not : TOKNOT",
"not :",
"keep : TOKKEEP",
"keep :",
"disabled : TOKDISABLED",
"disabled :",
"port : TOKPORT replstrv",
"port : TOKPORT numv",
"server : TOKSERVER replstrv port",
"server : TOKSERVER replstrv",
"to :",
"to : TOKTO strv",
"from :",
"from : TOKFROM strv",
"compress : TOKCOMPRESS",
"compress :",
"actitem : execpipe strv",
"actitem : TOKREWRITE strv",
"actitem : writeappend strv",
"actitem : TOKMAILDIR strv",
"actitem : rmheaders",
"actitem : TOKADDHEADER strv val",
"actitem : TOKMBOX strv compress",
"actitem : imaptype server userpassnetrc folder1 verify nocrammd5 nologin",
"actitem : TOKSMTP server from to",
"actitem : TOKSTDOUT",
"actitem : TOKTAG strv optval",
"actitem : TOKADDTOCACHE replpathv TOKKEY strv",
"actitem : TOKREMOVEFROMCACHE replpathv TOKKEY strv",
"actitem : actions",
"actitem : TOKDROP",
"actitem : TOKKEEP",
"actlist : actlist actitem",
"actlist : actitem",
"defaction : TOKACTION replstrv users actitem",
"defaction : TOKACTION replstrv users '{' actlist '}'",
"accounts : accountp strv",
"accounts : accountp '{' replstrslist '}'",
"actions : actionp strv",
"actions : actionp '{' replstrslist '}'",
"cont :",
"cont : TOKCONTINUE",
"area :",
"area : TOKIN TOKALL",
"area : TOKIN TOKHEADERS",
"area : TOKIN TOKBODY",
"retrc : numv",
"retrc :",
"retre : casere",
"retre :",
"ltgt : '<'",
"ltgt : '>'",
"eqne : TOKEQ",
"eqne : TOKNE",
"cmp : ltgt",
"cmp : eqne",
"execpipe : TOKEXEC",
"execpipe : TOKPIPE",
"writeappend : TOKWRITE",
"writeappend : TOKAPPEND",
"exprop : TOKAND",
"exprop : TOKOR",
"expritem : not TOKALL",
"expritem : not casere area",
"expritem : not accounts",
"expritem : not execpipe strv user TOKRETURNS '(' retrc ',' retre ')'",
"expritem : not TOKTAGGED strv",
"expritem : not TOKSIZE ltgt size",
"expritem : not TOKSTRING strv TOKTO casere",
"expritem : not TOKINCACHE replpathv TOKKEY strv",
"expritem : not TOKMATCHED",
"expritem : not TOKUNMATCHED",
"expritem : not TOKAGE ltgt time",
"expritem : not TOKAGE TOKINVALID",
"expritem : not TOKATTACHMENT TOKCOUNT cmp numv",
"expritem : not TOKATTACHMENT TOKTOTALSIZE ltgt size",
"expritem : not TOKATTACHMENT TOKANYSIZE ltgt size",
"expritem : not TOKATTACHMENT TOKANYTYPE strv",
"expritem : not TOKATTACHMENT TOKANYNAME strv",
"exprlist : exprlist exprop expritem",
"exprlist : exprop expritem",
"expr : expritem",
"expr : expritem exprlist",
"perform : users actionp actitem cont",
"perform : users actionp '{' actlist '}' cont",
"perform : users actions cont",
"perform : '{'",
"close : '}'",
"rule : TOKMATCH expr perform",
"folderlist :",
"folderlist : folders",
"folder1 :",
"folder1 : folderp strv",
"groups : groupp replstrv",
"groups : groupp '{' stringslist '}'",
"nocrammd5 : TOKNOCRAMMD5",
"nocrammd5 :",
"nologin : TOKNOLOGIN",
"nologin :",
"uidl : TOKNOUIDL",
"uidl :",
"verify : TOKNOVERIFY",
"verify :",
"apop : TOKNOAPOP",
"apop :",
"only : TOKNEWONLY",
"only : TOKOLDONLY",
"poptype : TOKPOP3",
"poptype : TOKPOP3S",
"imaptype : TOKIMAP",
"imaptype : TOKIMAPS",
"nntptype : TOKNNTP",
"nntptype : TOKNNTPS",
"userpassnetrc : TOKUSER replstrv TOKPASS replstrv",
"userpassnetrc :",
"userpassnetrc : TOKUSER replstrv",
"userpassnetrc : TOKPASS replstrv",
"userpassreqd : TOKUSER replstrv TOKPASS replstrv",
"userpass : userpassreqd",
"userpass :",
"poponly : only TOKCACHE replpathv",
"poponly :",
"imaponly : only",
"imaponly :",
"fetchtype : poptype server userpassnetrc poponly apop verify uidl",
"fetchtype : TOKPOP3 TOKPIPE replstrv userpassreqd poponly apop",
"fetchtype : imaptype server userpassnetrc folderlist imaponly verify nocrammd5 nologin",
"fetchtype : TOKIMAP TOKPIPE replstrv userpass folderlist imaponly",
"fetchtype : TOKSTDIN",
"fetchtype : maildirs",
"fetchtype : mboxes",
"fetchtype : nntptype server userpassnetrc groups TOKCACHE replpathv verify",
"account : TOKACCOUNT replstrv disabled users fetchtype keep",

};
#endif

int      yydebug;
int      yynerrs;

int      yyerrflag;
int      yychar;
YYSTYPE  yyval;
YYSTYPE  yylval;

/* define the initial stack-sizes */
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH  YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH  500
#endif
#endif

#define YYINITSTACKSIZE 500

typedef struct {
    unsigned stacksize;
    short    *s_base;
    short    *s_mark;
    short    *s_last;
    YYSTYPE  *l_base;
    YYSTYPE  *l_mark;
} YYSTACKDATA;
/* variables for the parser stack */
static YYSTACKDATA yystack;
#line 2624 "parse.y"

/* Programs */
#line 1679 "y.tab.c"

#if YYDEBUG
#include <stdio.h>		/* needed for printf */
#endif

#include <stdlib.h>	/* needed for malloc, etc */
#include <string.h>	/* needed for memset */

/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack(YYSTACKDATA *data)
{
    int i;
    unsigned newsize;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;

    i = (int) (data->s_mark - data->s_base);
    newss = (short *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return -1;

    data->s_base = newss;
    data->s_mark = newss + i;

    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return -1;

    data->l_base = newvs;
    data->l_mark = newvs + i;

    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;
    return 0;
}

#if YYPURE || defined(YY_NO_LEAKS)
static void yyfreestack(YYSTACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
    memset(data, 0, sizeof(*data));
}
#else
#define yyfreestack(data) /* nothing */
#endif

#define YYABORT  goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab

int
YYPARSE_DECL()
{
    int yym, yyn, yystate;
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")) != 0)
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;

#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif

    if (yystack.s_base == NULL && yygrowstack(&yystack)) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
    yystate = 0;
    *yystack.s_mark = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
        {
            goto yyoverflow;
        }
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
        yychar = YYEMPTY;
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;

    yyerror("syntax error");

    goto yyerrlab;

yyerrlab:
    ++yynerrs;

yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yystack.s_mark]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yystack.s_mark, yytable[yyn]);
#endif
                if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
                {
                    goto yyoverflow;
                }
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yystack.s_mark);
#endif
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
                --yystack.s_mark;
                --yystack.l_mark;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = YYEMPTY;
        goto yyloop;
    }

yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    if (yym)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
    switch (yyn)
    {
case 26:
#line 366 "parse.y"
	{
	     yyval.string = yystack.l_mark[0].string;
     }
break;
case 27:
#line 371 "parse.y"
	{
	     yyval.string = yystack.l_mark[0].string;
     }
break;
case 28:
#line 378 "parse.y"
	{
		yyval.string = yystack.l_mark[0].string;
        }
break;
case 29:
#line 382 "parse.y"
	{
		yyval.string = NULL;
	}
break;
case 30:
#line 388 "parse.y"
	{
	       yyval.string = run_command(yystack.l_mark[0].string, parse_file->path);
	       xfree(yystack.l_mark[0].string);
       }
break;
case 31:
#line 393 "parse.y"
	{
	       yyval.string = yystack.l_mark[0].string;
       }
break;
case 32:
#line 397 "parse.y"
	{
	       struct macro	*macro;

	       if (strlen(yystack.l_mark[0].string) > MAXNAMESIZE)
		       yyerror("macro name too long: %s", yystack.l_mark[0].string);

	       if ((macro = find_macro(yystack.l_mark[0].string)) == NULL)
		       yyerror("undefined macro: %s", yystack.l_mark[0].string);
	       if (macro->type != MACRO_STRING)
		       yyerror("string macro expected: %s", yystack.l_mark[0].string);

	       yyval.string = xstrdup(macro->value.str);

	       xfree(yystack.l_mark[0].string);
       }
break;
case 33:
#line 416 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 34:
#line 421 "parse.y"
	{
	      size_t	size;

	      size = strlen(yystack.l_mark[-2].string) + strlen(yystack.l_mark[0].string) + 1;
	      yyval.string = xrealloc(yystack.l_mark[-2].string, 1, size);
	      strlcat(yyval.string, yystack.l_mark[0].string, size);
	      xfree(yystack.l_mark[0].string);
      }
break;
case 35:
#line 432 "parse.y"
	{
	      const char	*errstr;
	      char		*s;

	      s = run_command(yystack.l_mark[0].string, parse_file->path);

	      yyval.number = strtonum(s, 0, LLONG_MAX, &errstr);
	      if (errstr != NULL)
		      yyerror("number is %s", errstr);

	      xfree(s);

	      xfree(yystack.l_mark[0].string);
      }
break;
case 36:
#line 447 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
break;
case 37:
#line 451 "parse.y"
	{
	      struct macro	*macro;

	      if (strlen(yystack.l_mark[0].string) > MAXNAMESIZE)
		      yyerror("macro name too long: %s", yystack.l_mark[0].string);

	      if ((macro = find_macro(yystack.l_mark[0].string)) == NULL)
		      yyerror("undefined macro: %s", yystack.l_mark[0].string);
	      if (macro->type != MACRO_NUMBER)
		      yyerror("number macro expected: %s", yystack.l_mark[0].string);

	      yyval.number = macro->value.num;

	      xfree(yystack.l_mark[0].string);
      }
break;
case 38:
#line 470 "parse.y"
	{
		  struct replstr	rs;

		  rs.str = yystack.l_mark[0].string;
		  yyval.string = replacestr(&rs, parse_tags, NULL, NULL);
		  xfree(yystack.l_mark[0].string);
	  }
break;
case 39:
#line 481 "parse.y"
	{
		  struct replpath	rp;

		  rp.str = yystack.l_mark[0].string;
		  yyval.string = replacepath(&rp, parse_tags, NULL, NULL, conf.user_home);
		  xfree(yystack.l_mark[0].string);
	   }
break;
case 40:
#line 492 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
break;
case 41:
#line 497 "parse.y"
	{
	      yyval.number = yystack.l_mark[-1].number;
      }
break;
case 42:
#line 502 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / 1024)
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * 1024;
      }
break;
case 43:
#line 509 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / (1024 * 1024))
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * (1024 * 1024);
      }
break;
case 44:
#line 516 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / (1024 * 1024 * 1024))
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * (1024 * 1024 * 1024);
      }
break;
case 45:
#line 525 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
break;
case 46:
#line 530 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_HOUR)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_HOUR;
      }
break;
case 47:
#line 537 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_MINUTE)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_MINUTE;
      }
break;
case 48:
#line 544 "parse.y"
	{
	      yyval.number = yystack.l_mark[-1].number;
      }
break;
case 49:
#line 549 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_DAY)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_DAY;
      }
break;
case 50:
#line 556 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_WEEK)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_WEEK;
      }
break;
case 51:
#line 563 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_MONTH)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_MONTH;
      }
break;
case 52:
#line 570 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_YEAR)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_YEAR;
      }
break;
case 53:
#line 579 "parse.y"
	{
#if UINT64_MAX < LLONG_MAX
		if (yystack.l_mark[0].number > UINT64_MAX)
			yyerror("time too long");
#endif

		yyval.number = yystack.l_mark[0].number;
	}
break;
case 54:
#line 588 "parse.y"
	{
		yyval.number = -1;
	}
break;
case 55:
#line 595 "parse.y"
	{
	       struct cache	*cache;

	       TAILQ_FOREACH(cache, &conf.caches, entry) {
		       if (strcmp(cache->path, yystack.l_mark[-1].string) == 0)
			       yyerror("duplicate cache path");
	       }

	       cache = xcalloc(1, sizeof *cache);
	       cache->path = yystack.l_mark[-1].string;
	       cache->expire = yystack.l_mark[0].number;

	       TAILQ_INSERT_TAIL(&conf.caches, cache, entry);

	       log_debug2("added cache \"%s\": expire %lld", cache->path, yystack.l_mark[0].number);
       }
break;
case 56:
#line 615 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero maximum size");
	     if (yystack.l_mark[0].number > MAXMAILSIZE)
		     yyerror("maximum size too large: %lld", yystack.l_mark[0].number);
	     conf.max_size = yystack.l_mark[0].number;
     }
break;
case 57:
#line 624 "parse.y"
	{
	     if (yystack.l_mark[0].locks & LOCK_FCNTL && yystack.l_mark[0].locks & LOCK_FLOCK)
		     yyerror("fcntl and flock locking cannot be used together");
	     conf.lock_types = yystack.l_mark[0].locks;
     }
break;
case 58:
#line 631 "parse.y"
	{
	     if (conf.lock_file != NULL)
		     xfree(conf.lock_file);
	     conf.lock_file = yystack.l_mark[0].string;
     }
break;
case 59:
#line 637 "parse.y"
	{
	     conf.del_big = 1;
     }
break;
case 60:
#line 641 "parse.y"
	{
	     conf.allow_many = 1;
     }
break;
case 61:
#line 646 "parse.y"
	{
	     if (conf.def_user == NULL)
		     conf.def_user = yystack.l_mark[0].string;
     }
break;
case 62:
#line 652 "parse.y"
	{
	     if (conf.cmd_user == NULL)
		     conf.cmd_user = yystack.l_mark[0].string;
     }
break;
case 63:
#line 658 "parse.y"
	{
	     xfree(conf.strip_chars);
	     conf.strip_chars = yystack.l_mark[0].string;
     }
break;
case 64:
#line 664 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero timeout");
	     if (yystack.l_mark[0].number > INT_MAX / 1000)
		     yyerror("timeout too long: %lld", yystack.l_mark[0].number);
	     conf.timeout = yystack.l_mark[0].number * 1000;
     }
break;
case 65:
#line 673 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero queue-high");
	     if (yystack.l_mark[0].number > MAXQUEUEVALUE)
		     yyerror("queue-high too big: %lld", yystack.l_mark[0].number);
	     if (conf.queue_low != -1 && yystack.l_mark[0].number <= conf.queue_low)
		     yyerror("queue-high must be larger than queue-low");
	     conf.queue_high = yystack.l_mark[0].number;
     }
break;
case 66:
#line 684 "parse.y"
	{
	     if (yystack.l_mark[0].number > MAXQUEUEVALUE)
		     yyerror("queue-low too big: %lld", yystack.l_mark[0].number);
	     if (conf.queue_high == -1)
		     yyerror("queue-high not specified");
	     if (yystack.l_mark[0].number >= conf.queue_high)
		     yyerror("queue-low must be smaller than queue-high");
	     conf.queue_low = yystack.l_mark[0].number;
     }
break;
case 67:
#line 695 "parse.y"
	{
	     if (yystack.l_mark[0].number > INT_MAX)
		     yyerror("parallel-accounts too big: %lld", yystack.l_mark[0].number);
	     if (yystack.l_mark[0].number == 0)
		     yyerror("parallel-accounts cannot be zero");
	     conf.max_accts = yystack.l_mark[0].number;
     }
break;
case 68:
#line 704 "parse.y"
	{
	     if (conf.proxy != NULL) {
		     xfree(conf.proxy->server.host);
		     xfree(conf.proxy->server.port);
		     if (conf.proxy->user != NULL)
			     xfree(conf.proxy->user);
		     if (conf.proxy->pass != NULL)
			     xfree(conf.proxy->pass);
	     }
	     if ((conf.proxy = getproxy(yystack.l_mark[0].string)) == NULL)
		     yyerror("invalid proxy");
	     xfree(yystack.l_mark[0].string);
     }
break;
case 69:
#line 718 "parse.y"
	{
	     conf.verify_certs = 1;
     }
break;
case 70:
#line 722 "parse.y"
	{
	     conf.impl_act = DECISION_KEEP;
     }
break;
case 71:
#line 726 "parse.y"
	{
	     conf.impl_act = DECISION_DROP;
     }
break;
case 72:
#line 731 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("invalid purge-after value: 0");
	     if (yystack.l_mark[0].number > UINT_MAX)
		     yyerror("purge-after value too large: %lld", yystack.l_mark[0].number);

	     conf.purge_after = yystack.l_mark[0].number;
     }
break;
case 73:
#line 740 "parse.y"
	{
	     conf.purge_after = 0;
     }
break;
case 74:
#line 744 "parse.y"
	{
	     conf.no_received = 1;
     }
break;
case 75:
#line 748 "parse.y"
	{
	     conf.no_create = 1;
     }
break;
case 76:
#line 752 "parse.y"
	{
	     conf.file_group = -1;
     }
break;
case 77:
#line 757 "parse.y"
	{
	     conf.file_group = yystack.l_mark[0].localgid;
     }
break;
case 78:
#line 761 "parse.y"
	{
	     conf.file_umask = umask(0);
	     umask(conf.file_umask);
     }
break;
case 79:
#line 767 "parse.y"
	{
	     ARRAY_FREEALL(conf.user_order);
	     conf.user_order = yystack.l_mark[0].ufns;
     }
break;
case 80:
#line 773 "parse.y"
	{
	     char	s[8];
	     u_int	n;

	     /*
	      * We can't differentiate umasks in octal from normal numbers
	      * (requiring a leading zero a la C would be nice, but it would
	      * potentially break existing configs), so we need to fiddle to
	      * convert.
	      */
	     memset(s, 0, sizeof s);
	     xsnprintf(s, sizeof s, "%03lld", yystack.l_mark[0].number);
	     if (s[3] != '\0' || s[0] < '0' || s[0] > '7' ||
		 s[1] < 0 || s[1] > '7' || s[2] < '0' || s[2] > '7')
		     yyerror("invalid umask: %s", s);
	     if (sscanf(s, "%o", &n) != 1)
		     yyerror("invalid umask: %s", s);
	     conf.file_umask = n;
     }
break;
case 81:
#line 796 "parse.y"
	{
		  struct macro	*macro;

		  if (strlen(yystack.l_mark[-2].string) > MAXNAMESIZE)
			  yyerror("macro name too long: %s", yystack.l_mark[-2].string);

		  macro = xmalloc(sizeof *macro);
		  strlcpy(macro->name, yystack.l_mark[-2].string, sizeof macro->name);
		  macro->type = MACRO_STRING;
		  macro->value.str = yystack.l_mark[0].string;

		  if (parse_last == NULL)
			  TAILQ_INSERT_HEAD(&parse_macros, macro, entry);
		  else {
			  TAILQ_INSERT_AFTER(
			      &parse_macros, parse_last, macro, entry);
		  }

		  log_debug3("added macro \"%s\": \"%s\"", macro->name,
		      macro->value.str);
		  xfree(yystack.l_mark[-2].string);
	  }
break;
case 82:
#line 820 "parse.y"
	{
		  struct macro	*macro;

		  if (strlen(yystack.l_mark[-2].string) > MAXNAMESIZE)
			  yyerror("macro name too long: %s", yystack.l_mark[-2].string);

		  macro = xmalloc(sizeof *macro);
		  strlcpy(macro->name, yystack.l_mark[-2].string, sizeof macro->name);
		  macro->type = MACRO_NUMBER;
		  macro->value.num = yystack.l_mark[0].number;

		  if (parse_last == NULL)
			  TAILQ_INSERT_HEAD(&parse_macros, macro, entry);
		  else {
			  TAILQ_INSERT_AFTER(
			      &parse_macros, parse_last, macro, entry);
		  }

		  log_debug3("added macro \"%s\": %lld", macro->name,
		      macro->value.num);
		  xfree(yystack.l_mark[-2].string);
	  }
break;
case 83:
#line 846 "parse.y"
	{
		      if (*yystack.l_mark[0].string == '\0')
			      yyerror("empty string in list");

		      yyval.replstrs = yystack.l_mark[-1].replstrs;
		      ARRAY_EXPAND(yyval.replstrs, 1);
		      ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	      }
break;
case 84:
#line 856 "parse.y"
	{
		      if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		      yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		      ARRAY_INIT(yyval.replstrs);
		      ARRAY_EXPAND(yyval.replstrs, 1);
		      ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	      }
break;
case 85:
#line 869 "parse.y"
	{
		     if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		     yyval.strings = yystack.l_mark[-1].strings;
		     ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	     }
break;
case 86:
#line 878 "parse.y"
	{
		     if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		     yyval.strings = xmalloc(sizeof *yyval.strings);
		     ARRAY_INIT(yyval.strings);
		     ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	     }
break;
case 87:
#line 890 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid path");

		   yyval.strings = yystack.l_mark[-1].strings;
		   ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	   }
break;
case 88:
#line 899 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid path");

		   yyval.strings = xmalloc(sizeof *yyval.strings);
		   ARRAY_INIT(yyval.strings);
		   ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	   }
break;
case 89:
#line 910 "parse.y"
	{
	     yyval.ufn = &passwd_lookup;
     }
break;
case 90:
#line 914 "parse.y"
	{
#ifdef LOOKUP_COURIER
	     yyval.ufn = &courier_lookup;
#else
	     yyerror("support for lookup-order courier is not enabled");
#endif
     }
break;
case 91:
#line 925 "parse.y"
	{
		 yyval.ufns = yystack.l_mark[-1].ufns;
		 ARRAY_ADD(yyval.ufns, yystack.l_mark[0].ufn);
	 }
break;
case 92:
#line 931 "parse.y"
	{
		 yyval.ufns = xmalloc(sizeof *yyval.ufns);
		 ARRAY_INIT(yyval.ufns);
		 ARRAY_ADD(yyval.ufns, yystack.l_mark[0].ufn);
	 }
break;
case 93:
#line 940 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid header");

		   yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		   ARRAY_INIT(yyval.replstrs);
		   ARRAY_EXPAND(yyval.replstrs, 1);
		   ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	   }
break;
case 94:
#line 951 "parse.y"
	{
		   yyval.replstrs = yystack.l_mark[-1].replstrs;
	   }
break;
case 95:
#line 958 "parse.y"
	{
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid path");

		  yyval.strings = xmalloc(sizeof *yyval.strings);
		  ARRAY_INIT(yyval.strings);
		  ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	  }
break;
case 96:
#line 968 "parse.y"
	{
		  yyval.strings = yystack.l_mark[-1].strings;
	  }
break;
case 97:
#line 975 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid path");

		yyval.strings = xmalloc(sizeof *yyval.strings);
		ARRAY_INIT(yyval.strings);
		ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	}
break;
case 98:
#line 985 "parse.y"
	{
		yyval.strings = yystack.l_mark[-1].strings;
	}
break;
case 99:
#line 992 "parse.y"
	{
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid folder");

		 yyval.strings = xmalloc(sizeof *yyval.strings);
		 ARRAY_INIT(yyval.strings);
		 ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	 }
break;
case 100:
#line 1002 "parse.y"
	{
		 yyval.strings = yystack.l_mark[-1].strings;
	 }
break;
case 101:
#line 1008 "parse.y"
	{
	      yyval.locks = LOCK_FCNTL;
      }
break;
case 102:
#line 1012 "parse.y"
	{
	      yyval.locks = LOCK_FLOCK;
      }
break;
case 103:
#line 1016 "parse.y"
	{
	      yyval.locks = LOCK_DOTLOCK;
      }
break;
case 104:
#line 1023 "parse.y"
	{
		  yyval.locks = yystack.l_mark[-1].locks | yystack.l_mark[0].locks;
	  }
break;
case 105:
#line 1028 "parse.y"
	{
		  yyval.locks = yystack.l_mark[0].locks;
	  }
break;
case 106:
#line 1032 "parse.y"
	{
		  yyval.locks = 0;
	  }
break;
case 107:
#line 1039 "parse.y"
	{
		  struct group	*gr;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid group");

		  gr = getgrnam(yystack.l_mark[0].string);
		  if (gr == NULL)
			  yyerror("unknown group: %s", yystack.l_mark[0].string);
		  yyval.localgid = gr->gr_gid;
		  endgrent();

		  xfree(yystack.l_mark[0].string);
	  }
break;
case 108:
#line 1055 "parse.y"
	{
		  struct group	*gr;

		  if (yystack.l_mark[0].number > GID_MAX)
			  yyerror("invalid gid: %llu", yystack.l_mark[0].number);
		  gr = getgrgid(yystack.l_mark[0].number);
		  if (gr == NULL)
			  yyerror("unknown gid: %llu", yystack.l_mark[0].number);
		  yyval.localgid = gr->gr_gid;
		  endgrent();
	  }
break;
case 109:
#line 1069 "parse.y"
	{
	      yyval.string = NULL;
      }
break;
case 110:
#line 1074 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 111:
#line 1080 "parse.y"
	{
	       yyval.replstrs = NULL;
       }
break;
case 112:
#line 1085 "parse.y"
	{
	       yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
	       ARRAY_INIT(yyval.replstrs);
	       ARRAY_EXPAND(yyval.replstrs, 1);
	       ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
       }
break;
case 113:
#line 1093 "parse.y"
	{
	       yyval.replstrs = yystack.l_mark[-1].replstrs;
       }
break;
case 114:
#line 1100 "parse.y"
	{
		/* match case */
		yyval.re.flags = 0;
		yyval.re.str = yystack.l_mark[0].string;
        }
break;
case 115:
#line 1107 "parse.y"
	{
		/* ignore case */
		yyval.re.flags = RE_IGNCASE;
		yyval.re.str = yystack.l_mark[0].string;
	}
break;
case 116:
#line 1115 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 117:
#line 1119 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 118:
#line 1125 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 119:
#line 1129 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 120:
#line 1135 "parse.y"
	{
		  yyval.flag = 1;
          }
break;
case 121:
#line 1139 "parse.y"
	{
		  yyval.flag = 0;
	  }
break;
case 122:
#line 1146 "parse.y"
	{
	      if (*yystack.l_mark[0].string == '\0')
		      yyerror("invalid port");

	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 123:
#line 1154 "parse.y"
	{
	      if (yystack.l_mark[0].number == 0 || yystack.l_mark[0].number > 65535)
		      yyerror("invalid port");

	      xasprintf(&yyval.string, "%lld", yystack.l_mark[0].number);
      }
break;
case 124:
#line 1164 "parse.y"
	{
		if (*yystack.l_mark[-1].string == '\0')
			yyerror("invalid host");

		yyval.server.host = yystack.l_mark[-1].string;
		yyval.server.port = yystack.l_mark[0].string;
	}
break;
case 125:
#line 1173 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid host");

		yyval.server.host = yystack.l_mark[0].string;
		yyval.server.port = NULL;
	}
break;
case 126:
#line 1183 "parse.y"
	{
	    yyval.string = NULL;
    }
break;
case 127:
#line 1188 "parse.y"
	{
	    yyval.string = yystack.l_mark[0].string;
    }
break;
case 128:
#line 1194 "parse.y"
	{
	      yyval.string = NULL;
      }
break;
case 129:
#line 1199 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 130:
#line 1205 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 131:
#line 1209 "parse.y"
	{
		  yyval.flag = 0;
	  }
break;
case 132:
#line 1216 "parse.y"
	{
		 struct deliver_pipe_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid command");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_pipe;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->pipe = yystack.l_mark[-1].flag;
		 data->cmd.str = yystack.l_mark[0].string;
	 }
break;
case 133:
#line 1233 "parse.y"
	{
		 struct deliver_rewrite_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid command");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_rewrite;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->cmd.str = yystack.l_mark[0].string;
	 }
break;
case 134:
#line 1249 "parse.y"
	{
		 struct deliver_write_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_write;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->append = yystack.l_mark[-1].flag;
		 data->path.str = yystack.l_mark[0].string;
	 }
break;
case 135:
#line 1266 "parse.y"
	{
		 struct deliver_maildir_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_maildir;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->path.str = yystack.l_mark[0].string;
	 }
break;
case 136:
#line 1282 "parse.y"
	{
		 struct deliver_remove_header_data *data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_remove_header;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->hdrs = yystack.l_mark[0].replstrs;
	 }
break;
case 137:
#line 1295 "parse.y"
	{
		 struct deliver_add_header_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid header");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_add_header;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->hdr.str = yystack.l_mark[-1].string;
		 data->value.str = yystack.l_mark[0].string;
	 }
break;
case 138:
#line 1312 "parse.y"
	{
		 struct deliver_mbox_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_mbox;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->path.str = yystack.l_mark[-1].string;
		 data->compress = yystack.l_mark[0].flag;
	 }
break;
case 139:
#line 1331 "parse.y"
	{
		 struct deliver_imap_data	*data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_imap;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 if (yystack.l_mark[-4].userpass.user_netrc && yystack.l_mark[-4].userpass.pass_netrc)
			 find_netrc(yystack.l_mark[-5].server.host, &data->user, &data->pass);
		 else {
			 if (yystack.l_mark[-4].userpass.user_netrc)
				 find_netrc(yystack.l_mark[-5].server.host, &data->user, NULL);
			 else
				 data->user = yystack.l_mark[-4].userpass.user;
			 if (yystack.l_mark[-4].userpass.pass_netrc)
				 find_netrc(yystack.l_mark[-5].server.host, NULL, &data->pass);
			 else
				 data->pass = yystack.l_mark[-4].userpass.pass;
		 }

		 data->folder.str = yystack.l_mark[-3].string;
		 data->server.ssl = yystack.l_mark[-6].flag;
		 data->server.verify = yystack.l_mark[-2].flag;
		 data->server.host = yystack.l_mark[-5].server.host;
		 if (yystack.l_mark[-5].server.port != NULL)
			 data->server.port = yystack.l_mark[-5].server.port;
		 else if (yystack.l_mark[-6].flag)
			 data->server.port = xstrdup("imaps");
		 else
			 data->server.port = xstrdup("imap");
		 data->server.ai = NULL;
		 data->nocrammd5 = yystack.l_mark[-1].flag;
		 data->nologin = yystack.l_mark[0].flag;
	 }
break;
case 140:
#line 1370 "parse.y"
	{
		 struct deliver_smtp_data	*data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_smtp;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->server.host = yystack.l_mark[-2].server.host;
		 if (yystack.l_mark[-2].server.port != NULL)
			 data->server.port = yystack.l_mark[-2].server.port;
		 else
			 data->server.port = xstrdup("smtp");
		 data->server.ai = NULL;
		 data->from.str = yystack.l_mark[-1].string;
		 data->to.str = yystack.l_mark[0].string;
	 }
break;
case 141:
#line 1389 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_stdout;
	 }
break;
case 142:
#line 1395 "parse.y"
	{
		 struct deliver_tag_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid tag");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_tag;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[-1].string;
		 data->value.str = yystack.l_mark[0].string;
	 }
break;
case 143:
#line 1412 "parse.y"
	{
		 struct deliver_add_to_cache_data	*data;

		 if (*yystack.l_mark[-2].string == '\0')
			 yyerror("invalid path");
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid key");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_add_to_cache;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[0].string;
		 data->path = yystack.l_mark[-2].string;
	 }
break;
case 144:
#line 1431 "parse.y"
	{
		 struct deliver_remove_from_cache_data	*data;

		 if (*yystack.l_mark[-2].string == '\0')
			 yyerror("invalid path");
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid key");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_remove_from_cache;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[0].string;
		 data->path = yystack.l_mark[-2].string;
	 }
break;
case 145:
#line 1450 "parse.y"
	{
		 struct deliver_action_data	*data;

		 /*
		  * This is a special-case, handled when the list of delivery
		  * targets is resolved rather than by calling a deliver
		  * function, so the deliver pointer is NULL.
		  */
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = NULL;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->actions = yystack.l_mark[0].replstrs;
 	 }
break;
case 146:
#line 1467 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_drop;
	 }
break;
case 147:
#line 1472 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_keep;
	 }
break;
case 148:
#line 1480 "parse.y"
	{
		 yyval.actlist = yystack.l_mark[-1].actlist;

		 TAILQ_INSERT_TAIL(yyval.actlist, yystack.l_mark[0].actitem, entry);
		 yystack.l_mark[0].actitem->idx = parse_actionidx++;
	 }
break;
case 149:
#line 1488 "parse.y"
	{
		 yyval.actlist = xmalloc(sizeof *yyval.actlist);
		 TAILQ_INIT(yyval.actlist);

		 TAILQ_INSERT_HEAD(yyval.actlist, yystack.l_mark[0].actitem, entry);
		 yystack.l_mark[0].actitem->idx = 0;

		 parse_actionidx = 1;
	 }
break;
case 150:
#line 1502 "parse.y"
	{
		   struct action	*t;

		   if (strlen(yystack.l_mark[-2].string) >= MAXNAMESIZE)
			   yyerror("action name too long: %s", yystack.l_mark[-2].string);
		   if (*yystack.l_mark[-2].string == '\0')
			   yyerror("invalid action name");
		   if (find_action(yystack.l_mark[-2].string) != NULL)
			   yyerror("duplicate action: %s", yystack.l_mark[-2].string);

		   t = xmalloc(sizeof *t);
		   strlcpy(t->name, yystack.l_mark[-2].string, sizeof t->name);

		   t->list = xmalloc(sizeof *t->list);
		   TAILQ_INIT(t->list);
		   TAILQ_INSERT_HEAD(t->list, yystack.l_mark[0].actitem, entry);
		   yystack.l_mark[0].actitem->idx = 0;

		   t->users = yystack.l_mark[-1].replstrs;
		   TAILQ_INSERT_TAIL(&conf.actions, t, entry);

		   print_action(t);

		   xfree(yystack.l_mark[-2].string);
	   }
break;
case 151:
#line 1530 "parse.y"
	{
		   struct action	*t;

		   if (strlen(yystack.l_mark[-4].string) >= MAXNAMESIZE)
			   yyerror("action name too long: %s", yystack.l_mark[-4].string);
		   if (*yystack.l_mark[-4].string == '\0')
			   yyerror("invalid action name");
		   if (find_action(yystack.l_mark[-4].string) != NULL)
			   yyerror("duplicate action: %s", yystack.l_mark[-4].string);

		   t = xmalloc(sizeof *t);
		   strlcpy(t->name, yystack.l_mark[-4].string, sizeof t->name);

		   t->list = yystack.l_mark[-1].actlist;

		   t->users = yystack.l_mark[-3].replstrs;
		   TAILQ_INSERT_TAIL(&conf.actions, t, entry);

		   print_action(t);

		   xfree(yystack.l_mark[-4].string);
	   }
break;
case 152:
#line 1556 "parse.y"
	{
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid account name");
		  if (!have_accounts(yystack.l_mark[0].string))
			  yyerror("no matching accounts: %s", yystack.l_mark[0].string);

		  yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		  ARRAY_INIT(yyval.replstrs);
		  ARRAY_EXPAND(yyval.replstrs, 1);
		  ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	  }
break;
case 153:
#line 1569 "parse.y"
	{
		  yyval.replstrs = yystack.l_mark[-1].replstrs;
	  }
break;
case 154:
#line 1576 "parse.y"
	{
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid action name");

		 yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		 ARRAY_INIT(yyval.replstrs);
		 ARRAY_EXPAND(yyval.replstrs, 1);
		 ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	 }
break;
case 155:
#line 1587 "parse.y"
	{
		 yyval.replstrs = yystack.l_mark[-1].replstrs;
	 }
break;
case 156:
#line 1593 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 157:
#line 1597 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 158:
#line 1603 "parse.y"
	{
	      yyval.area = AREA_ANY;
      }
break;
case 159:
#line 1607 "parse.y"
	{
	      yyval.area = AREA_ANY;
      }
break;
case 160:
#line 1611 "parse.y"
	{
	      yyval.area = AREA_HEADERS;
      }
break;
case 161:
#line 1615 "parse.y"
	{
	      yyval.area = AREA_BODY;
      }
break;
case 162:
#line 1622 "parse.y"
	{
	       if (yystack.l_mark[0].number < 0 || yystack.l_mark[0].number > 255)
		       yyerror("invalid return code");

	       yyval.number = yystack.l_mark[0].number;
       }
break;
case 163:
#line 1629 "parse.y"
	{
	       yyval.number = -1;
       }
break;
case 164:
#line 1636 "parse.y"
	{
	       yyval.re = yystack.l_mark[0].re;
       }
break;
case 165:
#line 1640 "parse.y"
	{
	       yyval.re.str = NULL;
       }
break;
case 166:
#line 1646 "parse.y"
	{
	     yyval.cmp = CMP_LT;
     }
break;
case 167:
#line 1650 "parse.y"
	{
	     yyval.cmp = CMP_GT;
     }
break;
case 168:
#line 1656 "parse.y"
	{
	      yyval.cmp = CMP_EQ;
      }
break;
case 169:
#line 1660 "parse.y"
	{
	      yyval.cmp = CMP_NE;
      }
break;
case 170:
#line 1667 "parse.y"
	{
	     yyval.cmp = yystack.l_mark[0].cmp;
     }
break;
case 171:
#line 1672 "parse.y"
	{
	     yyval.cmp = yystack.l_mark[0].cmp;
     }
break;
case 172:
#line 1678 "parse.y"
	{
		  yyval.flag = 0;
	  }
break;
case 173:
#line 1682 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 174:
#line 1688 "parse.y"
	{
		     yyval.flag = 0;
	     }
break;
case 175:
#line 1692 "parse.y"
	{
		     yyval.flag = 1;
	     }
break;
case 176:
#line 1698 "parse.y"
	{
		yyval.exprop = OP_AND;
        }
break;
case 177:
#line 1702 "parse.y"
	{
		yyval.exprop = OP_OR;
	}
break;
case 178:
#line 1709 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_all;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
	  }
break;
case 179:
#line 1717 "parse.y"
	{
		  struct match_regexp_data	*data;
		  char				*cause;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_regexp;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->area = yystack.l_mark[0].area;

		  if (re_compile(&data->re, yystack.l_mark[-1].re.str, yystack.l_mark[-1].re.flags, &cause) != 0)
			  yyerror("%s", cause);
		  xfree(yystack.l_mark[-1].re.str);
	  }
break;
case 180:
#line 1736 "parse.y"
	{
		  struct match_account_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_account;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->accounts = yystack.l_mark[0].replstrs;
	  }
break;
case 181:
#line 1752 "parse.y"
	{
		  struct match_command_data	*data;
		  char				*cause;

		  if (*yystack.l_mark[-7].string == '\0' || (yystack.l_mark[-7].string[0] == '|' && yystack.l_mark[-7].string[1] == '\0'))
			  yyerror("invalid command");
		  if (yystack.l_mark[-3].number == -1 && yystack.l_mark[-1].re.str == NULL)
			  yyerror("return code or regexp must be specified");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_command;
		  yyval.expritem->inverted = yystack.l_mark[-9].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->user.str = yystack.l_mark[-6].string;
		  data->pipe = yystack.l_mark[-8].flag;
		  data->cmd.str = yystack.l_mark[-7].string;

		  data->ret = yystack.l_mark[-3].number;

		  if (yystack.l_mark[-1].re.str != NULL) {
			  if (re_compile(
			      &data->re, yystack.l_mark[-1].re.str, yystack.l_mark[-1].re.flags, &cause) != 0)
				  yyerror("%s", cause);
			  xfree(yystack.l_mark[-1].re.str);
		  }

	  }
break;
case 182:
#line 1784 "parse.y"
	{
		  struct match_tagged_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid tag");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_tagged;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->tag.str = yystack.l_mark[0].string;
	  }
break;
case 183:
#line 1802 "parse.y"
	{
		  struct match_size_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_size;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->size = yystack.l_mark[0].number;
		  data->cmp = yystack.l_mark[-1].cmp;
	  }
break;
case 184:
#line 1824 "parse.y"
	{
		  struct match_string_data	*data;
		  char				*cause;

		  if (*yystack.l_mark[-2].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_string;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->str.str = yystack.l_mark[-2].string;
		  if (re_compile(
		      &data->re, yystack.l_mark[0].re.str, yystack.l_mark[0].re.flags|RE_NOSUBST, &cause) != 0)
			  yyerror("%s", cause);
		  xfree(yystack.l_mark[0].re.str);
	  }
break;
case 185:
#line 1847 "parse.y"
	{
		  struct match_in_cache_data	*data;

		  if (*yystack.l_mark[-2].string == '\0')
			  yyerror("invalid path");
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid key");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_in_cache;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->key.str = yystack.l_mark[0].string;
		  data->path = yystack.l_mark[-2].string;
	  }
break;
case 186:
#line 1868 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_matched;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
          }
break;
case 187:
#line 1876 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_unmatched;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
          }
break;
case 188:
#line 1884 "parse.y"
	{
		  struct match_age_data	*data;

		  if (yystack.l_mark[0].number == 0)
			  yyerror("invalid time");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_age;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->time = yystack.l_mark[0].number;
		  data->cmp = yystack.l_mark[-1].cmp;
	  }
break;
case 189:
#line 1903 "parse.y"
	{
		  struct match_age_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_age;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->time = -1;
	  }
break;
case 190:
#line 1918 "parse.y"
	{
		  struct match_attachment_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_COUNT;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.num = yystack.l_mark[0].number;
	  }
break;
case 191:
#line 1935 "parse.y"
	{
		  struct match_attachment_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_TOTALSIZE;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.size = yystack.l_mark[0].number;
	  }
break;
case 192:
#line 1957 "parse.y"
	{
		  struct match_attachment_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYSIZE;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.size = yystack.l_mark[0].number;
	  }
break;
case 193:
#line 1979 "parse.y"
	{
		  struct match_attachment_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYTYPE;
		  data->value.str.str = yystack.l_mark[0].string;
	  }
break;
case 194:
#line 1998 "parse.y"
	{
		  struct match_attachment_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYNAME;
		  data->value.str.str = yystack.l_mark[0].string;
	  }
break;
case 195:
#line 2020 "parse.y"
	{
		  yyval.expr = yystack.l_mark[-2].expr;

		  yystack.l_mark[0].expritem->op = yystack.l_mark[-1].exprop;
		  TAILQ_INSERT_TAIL(yyval.expr, yystack.l_mark[0].expritem, entry);
	  }
break;
case 196:
#line 2028 "parse.y"
	{
		  yyval.expr = xmalloc(sizeof *yyval.expr);
		  TAILQ_INIT(yyval.expr);

		  yystack.l_mark[0].expritem->op = yystack.l_mark[-1].exprop;
		  TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[0].expritem, entry);
	  }
break;
case 197:
#line 2039 "parse.y"
	{
	      yyval.expr = xmalloc(sizeof *yyval.expr);
	      TAILQ_INIT(yyval.expr);

	      TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[0].expritem, entry);
      }
break;
case 198:
#line 2047 "parse.y"
	{
	      yyval.expr = yystack.l_mark[0].expr;

	      TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[-1].expritem, entry);
      }
break;
case 199:
#line 2057 "parse.y"
	{
		 struct action	*t;

		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-3].replstrs;

		 t = yyval.rule->lambda = xcalloc(1, sizeof *yyval.rule->lambda);
		 xsnprintf(t->name, sizeof t->name, "<rule %u>", yyval.rule->idx);
		 t->users = NULL;
		 t->list = xmalloc(sizeof *t->list);
		 TAILQ_INIT(t->list);
		 TAILQ_INSERT_HEAD(t->list, yystack.l_mark[-1].actitem, entry);
		 yystack.l_mark[-1].actitem->idx = 0;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
break;
case 200:
#line 2083 "parse.y"
	{
		 struct action	*t;

		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-5].replstrs;

		 t = yyval.rule->lambda = xcalloc(1, sizeof *yyval.rule->lambda);
		 xsnprintf(t->name, sizeof t->name, "<rule %u>", yyval.rule->idx);
		 t->users = NULL;
		 t->list = yystack.l_mark[-2].actlist;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
break;
case 201:
#line 2106 "parse.y"
	{
		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->lambda = NULL;
		 yyval.rule->actions = yystack.l_mark[-1].replstrs;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-2].replstrs;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
break;
case 202:
#line 2121 "parse.y"
	{
		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->lambda = NULL;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = 0;
		 yyval.rule->users = NULL;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);

		 ARRAY_ADD(&parse_rulestack, parse_rule);
		 parse_rule = yyval.rule;
	 }
break;
case 203:
#line 2141 "parse.y"
	{
	       if (parse_rule == NULL)
		       yyerror("missing {");

	       parse_rule = ARRAY_LAST(&parse_rulestack);
	       ARRAY_TRUNC(&parse_rulestack, 1);
       }
break;
case 204:
#line 2152 "parse.y"
	{
	      yystack.l_mark[0].rule->expr = yystack.l_mark[-1].expr;
	      print_rule(yystack.l_mark[0].rule);
      }
break;
case 205:
#line 2159 "parse.y"
	{
		    yyval.strings = xmalloc(sizeof *yyval.strings);
		    ARRAY_INIT(yyval.strings);
		    ARRAY_ADD(yyval.strings, xstrdup("INBOX"));
	    }
break;
case 206:
#line 2166 "parse.y"
	{
		    yyval.strings = yystack.l_mark[0].strings;
	    }
break;
case 207:
#line 2172 "parse.y"
	{
		 yyval.string = xstrdup("INBOX");
	 }
break;
case 208:
#line 2177 "parse.y"
	{
		 yyval.string = yystack.l_mark[0].string;
	 }
break;
case 209:
#line 2185 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid group");

		yyval.strings = xmalloc(sizeof *yyval.strings);
		ARRAY_INIT(yyval.strings);
		ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	}
break;
case 210:
#line 2195 "parse.y"
	{
		yyval.strings = yystack.l_mark[-1].strings;
	}
break;
case 211:
#line 2201 "parse.y"
	{
		   yyval.flag = 1;
	   }
break;
case 212:
#line 2205 "parse.y"
	{
		   yyval.flag = 0;
	   }
break;
case 213:
#line 2211 "parse.y"
	{
		 yyval.flag = 1;
	 }
break;
case 214:
#line 2215 "parse.y"
	{
		 yyval.flag = 0;
	 }
break;
case 215:
#line 2221 "parse.y"
	{
		yyval.flag = 0;
	}
break;
case 216:
#line 2225 "parse.y"
	{
		yyval.flag = 1;
	}
break;
case 217:
#line 2231 "parse.y"
	{
		yyval.flag = 0;
	}
break;
case 218:
#line 2235 "parse.y"
	{
		yyval.flag = 1;
	}
break;
case 219:
#line 2241 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 220:
#line 2245 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 221:
#line 2251 "parse.y"
	{
	      yyval.only = FETCH_ONLY_NEW;
      }
break;
case 222:
#line 2255 "parse.y"
	{
	      yyval.only = FETCH_ONLY_OLD;
      }
break;
case 223:
#line 2261 "parse.y"
	{
		 yyval.flag = 0;
         }
break;
case 224:
#line 2265 "parse.y"
	{
		 yyval.flag = 1;
	 }
break;
case 225:
#line 2271 "parse.y"
	{
		  yyval.flag = 0;
          }
break;
case 226:
#line 2275 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 227:
#line 2281 "parse.y"
	{
		  yyval.flag = 0;
          }
break;
case 228:
#line 2285 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 229:
#line 2292 "parse.y"
	{
		       if (*yystack.l_mark[-2].string == '\0')
			       yyerror("invalid user");
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid pass");

		       yyval.userpass.user = yystack.l_mark[-2].string;
		       yyval.userpass.user_netrc = 0;
		       yyval.userpass.pass = yystack.l_mark[0].string;
		       yyval.userpass.pass_netrc = 0;
	       }
break;
case 230:
#line 2304 "parse.y"
	{
		       yyval.userpass.user = NULL;
		       yyval.userpass.user_netrc = 1;
		       yyval.userpass.pass = NULL;
		       yyval.userpass.pass_netrc = 1;
	       }
break;
case 231:
#line 2312 "parse.y"
	{
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid user");

		       yyval.userpass.user = yystack.l_mark[0].string;
		       yyval.userpass.user_netrc = 0;
		       yyval.userpass.pass = NULL;
		       yyval.userpass.pass_netrc = 1;
	       }
break;
case 232:
#line 2323 "parse.y"
	{
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid pass");

		       yyval.userpass.user = NULL;
		       yyval.userpass.user_netrc = 1;
		       yyval.userpass.pass = yystack.l_mark[0].string;
		       yyval.userpass.pass_netrc = 0;
	       }
break;
case 233:
#line 2336 "parse.y"
	{
		      if (*yystack.l_mark[-2].string == '\0')
			      yyerror("invalid user");
		      if (*yystack.l_mark[0].string == '\0')
			      yyerror("invalid pass");

		      yyval.userpass.user = yystack.l_mark[-2].string;
		      yyval.userpass.user_netrc = 0;
		      yyval.userpass.pass = yystack.l_mark[0].string;
		      yyval.userpass.pass_netrc = 0;
	      }
break;
case 234:
#line 2351 "parse.y"
	{
		  yyval.userpass.user = yystack.l_mark[0].userpass.user;
		  yyval.userpass.user_netrc = yystack.l_mark[0].userpass.user_netrc;
		  yyval.userpass.pass = yystack.l_mark[0].userpass.pass;
		  yyval.userpass.pass_netrc = yystack.l_mark[0].userpass.pass_netrc;
	  }
break;
case 235:
#line 2358 "parse.y"
	{
		  yyval.userpass.user = NULL;
		  yyval.userpass.user_netrc = 0;
		  yyval.userpass.pass = NULL;
		  yyval.userpass.pass_netrc = 0;
	  }
break;
case 236:
#line 2368 "parse.y"
	{
		 yyval.poponly.path = yystack.l_mark[0].string;
		 yyval.poponly.only = yystack.l_mark[-2].only;
	 }
break;
case 237:
#line 2373 "parse.y"
	{
		 yyval.poponly.path = NULL;
		 yyval.poponly.only = FETCH_ONLY_ALL;
	 }
break;
case 238:
#line 2381 "parse.y"
	{
		  yyval.only = yystack.l_mark[0].only;
	  }
break;
case 239:
#line 2385 "parse.y"
	{
		  yyval.only = FETCH_ONLY_ALL;
	  }
break;
case 240:
#line 2395 "parse.y"
	{
		   struct fetch_pop3_data	*data;

		   yyval.fetch.fetch = &fetch_pop3;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-4].userpass.user_netrc && yystack.l_mark[-4].userpass.pass_netrc)
			  find_netrc(yystack.l_mark[-5].server.host, &data->user, &data->pass);
		   else {
			   if (yystack.l_mark[-4].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-5].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-4].userpass.user;
			   if (yystack.l_mark[-4].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-5].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-4].userpass.pass;
		   }

		   data->server.ssl = yystack.l_mark[-6].flag;
		   data->server.verify = yystack.l_mark[-1].flag;
		   data->server.host = yystack.l_mark[-5].server.host;
		   if (yystack.l_mark[-5].server.port != NULL)
			   data->server.port = yystack.l_mark[-5].server.port;
		   else if (yystack.l_mark[-6].flag)
			   data->server.port = xstrdup("pop3s");
		   else
			   data->server.port = xstrdup("pop3");
		   data->server.ai = NULL;
		   data->apop = yystack.l_mark[-2].flag;
		   data->uidl = yystack.l_mark[0].flag;

		   data->path = yystack.l_mark[-3].poponly.path;
		   data->only = yystack.l_mark[-3].poponly.only;
	   }
break;
case 241:
#line 2435 "parse.y"
	{
		   struct fetch_pop3_data	*data;

		   yyval.fetch.fetch = &fetch_pop3pipe;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->user = yystack.l_mark[-2].userpass.user;
		   data->pass = yystack.l_mark[-2].userpass.pass;
		   data->pipecmd = yystack.l_mark[-3].string;
		   if (data->pipecmd == NULL || *data->pipecmd == '\0')
			   yyerror("invalid pipe command");
		   data->apop = yystack.l_mark[0].flag;
		   data->path = yystack.l_mark[-1].poponly.path;
		   data->only = yystack.l_mark[-1].poponly.only;
	   }
break;
case 242:
#line 2456 "parse.y"
	{
		   struct fetch_imap_data	*data;

		   yyval.fetch.fetch = &fetch_imap;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-5].userpass.user_netrc && yystack.l_mark[-5].userpass.pass_netrc)
			   find_netrc(yystack.l_mark[-6].server.host, &data->user, &data->pass);
		   else {
			   if (yystack.l_mark[-5].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-5].userpass.user;
			   if (yystack.l_mark[-5].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-5].userpass.pass;
		   }

		   data->folders = yystack.l_mark[-4].strings;
		   data->server.ssl = yystack.l_mark[-7].flag;
		   data->server.verify = yystack.l_mark[-2].flag;
		   data->server.host = yystack.l_mark[-6].server.host;
		   if (yystack.l_mark[-6].server.port != NULL)
			   data->server.port = yystack.l_mark[-6].server.port;
		   else if (yystack.l_mark[-7].flag)
			   data->server.port = xstrdup("imaps");
		   else
			   data->server.port = xstrdup("imap");
		   data->server.ai = NULL;
		   data->only = yystack.l_mark[-3].only;
		   data->nocrammd5 = yystack.l_mark[-1].flag;
		   data->nologin = yystack.l_mark[0].flag;
	   }
break;
case 243:
#line 2495 "parse.y"
	{
		   struct fetch_imap_data	*data;

		   yyval.fetch.fetch = &fetch_imappipe;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->user = yystack.l_mark[-2].userpass.user;
		   data->pass = yystack.l_mark[-2].userpass.pass;
		   data->folders = yystack.l_mark[-1].strings;
		   data->pipecmd = yystack.l_mark[-3].string;
		   if (data->pipecmd == NULL || *data->pipecmd == '\0')
			   yyerror("invalid pipe command");
		   data->only = yystack.l_mark[0].only;
	   }
break;
case 244:
#line 2510 "parse.y"
	{
		   yyval.fetch.fetch = &fetch_stdin;
	   }
break;
case 245:
#line 2515 "parse.y"
	{
		   struct fetch_maildir_data	*data;

		   yyval.fetch.fetch = &fetch_maildir;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->maildirs = yystack.l_mark[0].strings;
	   }
break;
case 246:
#line 2525 "parse.y"
	{
		   struct fetch_mbox_data	*data;

		   yyval.fetch.fetch = &fetch_mbox;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->mboxes = yystack.l_mark[0].strings;
	   }
break;
case 247:
#line 2538 "parse.y"
	{
		   struct fetch_nntp_data	*data;
		   char				*cause;

		   if (*yystack.l_mark[-1].string == '\0')
			   yyerror("invalid cache");

		   yyval.fetch.fetch = &fetch_nntp;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-4].userpass.user_netrc && yystack.l_mark[-4].userpass.pass_netrc) {
			   if (find_netrc1(yystack.l_mark[-5].server.host,
			       &data->user, &data->pass, &cause) != 0) {
				   log_debug2("%s", cause);
				   xfree(cause);
				   data->user = NULL;
				   data->pass = NULL;
			   }

		   } else {
			   if (yystack.l_mark[-4].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-5].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-4].userpass.user;
			   if (yystack.l_mark[-4].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-5].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-4].userpass.pass;
		   }

		   data->names = yystack.l_mark[-3].strings;
		   data->path = yystack.l_mark[-1].string;
		   if (data->path == NULL || *data->path == '\0')
			   yyerror("invalid cache");

		   data->server.ssl = yystack.l_mark[-6].flag;
		   data->server.verify = yystack.l_mark[0].flag;
		   data->server.host = yystack.l_mark[-5].server.host;
		   if (yystack.l_mark[-5].server.port != NULL)
			   data->server.port = yystack.l_mark[-5].server.port;
		   else if (yystack.l_mark[-6].flag)
                           data->server.port = xstrdup("nntps");
                   else
			   data->server.port = xstrdup("nntp");
		   data->server.ai = NULL;
	   }
break;
case 248:
#line 2591 "parse.y"
	{
		 struct account		*a;
		 char			*su, desc[DESCBUFSIZE];

		 if (strlen(yystack.l_mark[-4].string) >= MAXNAMESIZE)
			 yyerror("account name too long: %s", yystack.l_mark[-4].string);
		 if (*yystack.l_mark[-4].string == '\0')
			 yyerror("invalid account name");
		 if (find_account(yystack.l_mark[-4].string) != NULL)
			 yyerror("duplicate account: %s", yystack.l_mark[-4].string);

		 a = xcalloc(1, sizeof *a);
		 strlcpy(a->name, yystack.l_mark[-4].string, sizeof a->name);
		 a->keep = yystack.l_mark[0].flag;
		 a->disabled = yystack.l_mark[-3].flag;
		 a->users = yystack.l_mark[-2].replstrs;
		 a->fetch = yystack.l_mark[-1].fetch.fetch;
		 a->data = yystack.l_mark[-1].fetch.data;
		 TAILQ_INSERT_TAIL(&conf.accounts, a, entry);

		 if (a->users != NULL)
			 su = fmt_replstrs(" users=", a->users);
		 else
			 su = xstrdup("");
		 a->fetch->desc(a, desc, sizeof desc);
		 log_debug2("added account \"%s\":%s fetch=%s", a->name, su,
		     desc);
		 xfree(su);

		 xfree(yystack.l_mark[-4].string);
	 }
break;
#line 4270 "y.tab.c"
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
        if (yychar < 0)
        {
            if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yystack.s_mark, yystate);
#endif
    if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
    {
        goto yyoverflow;
    }
    *++yystack.s_mark = (short) yystate;
    *++yystack.l_mark = yyval;
    goto yyloop;

yyoverflow:
    yyerror("yacc stack overflow");

yyabort:
    yyfreestack(&yystack);
    return (1);

yyaccept:
    yyfreestack(&yystack);
    return (0);
}
